@@ -20,9 +20,13 @@
 
 #include "renderjob.h"
 
+#include <stdlib.h> // for getenv, posix portable to Windows: http://msdn.microsoft.com/en-us/library/tehxacec(VS.80).aspx
+
 #include <QtDBus>
 #include <QFile>
 #include <QThread>
+#include <QStringList>
+
 
 // Can't believe I need to do this to sleep.
 class SleepThread : QThread
@@ -40,7 +44,8 @@ RenderJob::RenderJob(bool erase, bool usekuiserver, const QString &renderer, con
         QObject(),
         m_jobUiserver(NULL),
         m_kdenliveinterface(NULL),
-        m_usekuiserver(usekuiserver)
+        m_usekuiserver(usekuiserver),
+        m_enablelog(false)
 {
     m_scenelist = scenelist;
     m_dest = dest;
@@ -64,37 +69,48 @@ RenderJob::RenderJob(bool erase, bool usekuiserver, const QString &renderer, con
     m_dualpass = false;
     if (args.contains("pass=1")) m_dualpass = true;
 
-    connect(m_renderProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotIsOver(int, QProcess::ExitStatus)));
+    connect(m_renderProcess, SIGNAL(stateChanged(QProcess::ProcessState)), this, SLOT(slotCheckProcess(QProcess::ProcessState)));
+    //connect(m_renderProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotIsOver(int, QProcess::ExitStatus)));
     m_renderProcess->setReadChannel(QProcess::StandardError);
 
-    /*
-    // Create a log of every render process.
-    m_logfile.setAutoRemove(false);
-    m_logfile.setFileTemplate(QDir::tempPath() + "/kdenlive_render.log.XXXXXXXX");
-    if (m_logfile.open()) {
-        qDebug() << "Writing render log to " << m_logfile.fileName();
+    m_enablelog = (getenv("KDENLIVE_RENDER_LOG") != NULL);
+    if (m_enablelog) {
+        // Create a log of every render process.
+        m_logfile.setAutoRemove(false);
+        m_logfile.setFileTemplate(QDir::tempPath() + "/kdenlive_render.log.XXXXXXXX");
+        if (m_logfile.open()) {
+            qDebug() << "Writing render log to " << m_logfile.fileName();
 
-    } else {
-        qDebug() << "Unable to log to " << m_logfile.fileName();
+        } else {
+            qDebug() << "Unable to log to " << m_logfile.fileName();
+        }
+        m_logstream.setDevice(&m_logfile);
+        QString tmplist = scenelist;
+        if (tmplist.contains("consumer:")) {
+            QStringList tl = tmplist.split("consumer:");
+            if (tl.count() == 2) {
+                tmplist = tl[1];
+            }
+        }
+        m_logstream << "Log starting. Dumping contents of " << tmplist << endl;
+        QFile file(tmplist);
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            m_logstream << "Unable to read contents of " << tmplist << endl;
+        } else {
+            m_logstream.flush();
+            QTextStream in(&file);
+            m_logstream << in.readAll() << endl;
+        }
     }
-    m_logstream.setDevice(&m_logfile);
-    m_logstream << "Log starting. Dumping contents of " << scenelist << endl;
-    QFile file(scenelist);
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        m_logstream << "Unable to read contents of " << scenelist << endl;
-    } else {
-        m_logstream.flush();
-        QTextStream in(&file);
-        m_logstream << in.readAll() << endl;
-    }
-    */
 }
 
 
 RenderJob::~RenderJob()
 {
     if (m_renderProcess) delete m_renderProcess;
-    // m_logfile.close();
+    if (m_enablelog) {
+        m_logfile.close();
+    }
 }
 
 void RenderJob::slotAbort(const QString& url)
@@ -104,7 +120,7 @@ void RenderJob::slotAbort(const QString& url)
 
 void RenderJob::slotAbort()
 {
-    qDebug() << "Kdenlive-render: JOB ABORTED BY USER...";
+    qDebug() << "Kdenlive-render: JOB ABORTED BY USER...";
     m_renderProcess->kill();
 
     if (m_kdenliveinterface) {
@@ -119,11 +135,11 @@ void RenderJob::slotAbort()
     }
     QFile f(m_dest);
     f.remove();
-    /*
-    m_logstream << "Job aborted by user" << endl;
-    m_logstream.flush();
-    m_logfile.close();
-    */
+    if (m_enablelog) {
+        m_logstream << "Job aborted by user" << endl;
+        m_logstream.flush();
+        m_logfile.close();
+    }
     qApp->quit();
 }
 
@@ -132,7 +148,7 @@ void RenderJob::receivedStderr()
     QString result = QString(m_renderProcess->readAllStandardError()).simplified();
     if (!result.startsWith("Current Frame")) m_errorMessage.append(result + "<br>");
     else {
-        // m_logstream << "ReceivedStderr from inigo: " << result << endl;
+        if (m_enablelog) m_logstream << "ReceivedStderr from melt: " << result << endl;
         result = result.section(' ', -1);
         int pro = result.toInt();
         if (pro < 0 || pro > 100) return;
@@ -142,14 +158,14 @@ void RenderJob::receivedStderr()
                 if (!m_kdenliveinterface->isValid()) {
                     delete m_kdenliveinterface;
                     m_kdenliveinterface = NULL;
-                    // qDebug() << "BROKEN COMMUNICATION WITH KDENLIVE";
+                    // qDebug() << "BROKEN COMMUNICATION WITH KDENLIVE";
                 } else {
                     m_dbusargs[1] = pro;
                     m_kdenliveinterface->callWithArgumentList(QDBus::NoBlock, "setRenderingProgress", m_dbusargs);
                 }
             } else if (pro % 5 == 0) {
                 // Try to restart communication with Kdenlive every 5 percents
-                // qDebug() << "TRYING TO RESTART COMMUNICATION WITH KDENLIVE";
+                // qDebug() << "TRYING TO RESTART COMMUNICATION WITH KDENLIVE";
                 initKdenliveDbusInterface();
             }
 
@@ -169,10 +185,10 @@ void RenderJob::start()
     if (interface && m_usekuiserver) {
         if (!interface->isServiceRegistered("org.kde.JobViewServer")) {
             qDebug() << "No org.kde.JobViewServer registered, trying to start kuiserver";
-            // m_logstream << "No org.kde.JobViewServer registered, trying to start kuiserver";
+            if (m_enablelog) m_logstream << "No org.kde.JobViewServer registered, trying to start kuiserver";
             if (QProcess::startDetached("kuiserver")) {
                 qDebug() << "Started kuiserver";
-                // m_logstream << "Started kuiserver";
+                if (m_enablelog) m_logstream << "Started kuiserver";
                 // Give it a couple of seconds to start
                 QTime t;
                 t.start();
@@ -181,7 +197,7 @@ void RenderJob::start()
                 }
             } else {
                 qDebug() << "Failed to start kuiserver";
-                // m_logstream << "Failed to start kuiserver";
+                if (m_enablelog) m_logstream << "Failed to start kuiserver";
             }
         }
 
@@ -205,7 +221,7 @@ void RenderJob::start()
     // Because of the logging, we connect to stderr in all cases.
     connect(m_renderProcess, SIGNAL(readyReadStandardError()), this, SLOT(receivedStderr()));
     m_renderProcess->start(m_prog, m_args);
-    // m_logstream << "Started render process: " << m_prog << " " << m_args.join(" ") << endl;
+    if (m_enablelog) m_logstream << "Started render process: " << m_prog << " " << m_args.join(" ") << endl;
     qDebug() << "Started render process: " << m_prog << " " << m_args.join(" ");
 }
 
@@ -240,14 +256,21 @@ void RenderJob::initKdenliveDbusInterface()
 }
 
 
-void RenderJob::slotIsOver(int /*exitcode*/, QProcess::ExitStatus status)
+void RenderJob::slotCheckProcess(QProcess::ProcessState state)
+{
+    if (state == QProcess::NotRunning) slotIsOver(m_renderProcess->exitStatus());
+}
+
+
+
+void RenderJob::slotIsOver(QProcess::ExitStatus status)
 {
     if (m_jobUiserver) m_jobUiserver->call("terminate", QString());
     if (m_erase) {
         QFile f(m_scenelist);
         f.remove();
     }
-    if (status == QProcess::CrashExit) {
+    if (status == QProcess::CrashExit || m_renderProcess->error() != QProcess::UnknownError) {
         // rendering crashed
         if (m_kdenliveinterface) {
             m_dbusargs[1] = (int) - 2;
@@ -256,7 +279,7 @@ void RenderJob::slotIsOver(int /*exitcode*/, QProcess::ExitStatus status)
         }
         QStringList args;
         args << "--error" << tr("Rendering of %1 aborted, resulting video will probably be corrupted.").arg(m_dest);
-        // m_logstream << "Rendering of " << m_dest << " aborted, resulting video will probably be corrupted." << endl;
+        if (m_enablelog) m_logstream << "Rendering of " << m_dest << " aborted, resulting video will probably be corrupted." << endl;
         qDebug() << "Rendering of " << m_dest << " aborted, resulting video will probably be corrupted.";
         QProcess::startDetached("kdialog", args);
         qApp->quit();
@@ -287,10 +310,10 @@ void RenderJob::slotIsOver(int /*exitcode*/, QProcess::ExitStatus status)
             m.setArguments(args);
             QDBusMessage replyMsg = QDBusConnection::sessionBus().call(m);
         }
-        // m_logstream << "Rendering of " << m_dest << " finished" << endl;
+        if (m_enablelog) m_logstream << "Rendering of " << m_dest << " finished" << endl;
         qDebug() << "Rendering of " << m_dest << " finished";
         if (!m_dualpass && m_player != "-") {
-            // m_logstream << "Starting player" << endl;
+            if (m_enablelog) m_logstream << "Starting player" << endl;
             QStringList args;
             args << m_dest;
             QProcess::startDetached(m_player, args);
