@@ -41,10 +41,11 @@ public slots:
     void start();
 
 private slots:
-    void slotIsOver(int exitcode, QProcess::ExitStatus status);
+    void slotIsOver(QProcess::ExitStatus status);
     void receivedStderr();
     void slotAbort();
     void slotAbort(const QString& url);
+    void slotCheckProcess(QProcess::ProcessState state);
 
 private:
     QString m_scenelist;
@@ -63,6 +64,11 @@ private:
     QTime m_startTime;
     void initKdenliveDbusInterface();
     bool m_usekuiserver;
+    bool m_enablelog;
+    /** \brief Used to create a temporary file for logging */
+    QTemporaryFile m_logfile;
+    /** \brief Used to write to the log file */
+    QTextStream m_logstream;
 
 signals:
     void renderingFinished();
