@@ -32,57 +32,52 @@
 AbstractClipItem::AbstractClipItem(const ItemInfo info, const QRectF& rect, double fps) :
         QObject(),
         QGraphicsRectItem(rect),
-        m_track(0),
+        m_info(info),
         m_editedKeyframe(-1),
         m_selectedKeyframe(0),
         m_keyframeFactor(1),
         m_fps(fps)
 {
-    setFlags(/*QGraphicsItem::ItemClipsToShape | */QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
-    setTrack(info.track);
-    m_startPos = info.startPos;
-    m_cropDuration = info.endPos - info.startPos;
+    setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
 }
 
 ItemInfo AbstractClipItem::info() const
 {
-    ItemInfo itemInfo;
-    itemInfo.startPos = startPos();
-    itemInfo.endPos = endPos();
-    itemInfo.cropStart = m_cropStart;
-    itemInfo.track = track();
-    return itemInfo;
+    ItemInfo info = m_info;
+    info.cropStart = cropStart();
+    info.endPos = endPos();
+    return info;
 }
 
 GenTime AbstractClipItem::endPos() const
 {
-    return m_startPos + m_cropDuration;
+    return m_info.startPos + m_info.cropDuration;
 }
 
 int AbstractClipItem::track() const
 {
-    return m_track;
+    return m_info.track;
 }
 
 GenTime AbstractClipItem::cropStart() const
 {
-    return m_cropStart;
+    return m_info.cropStart;
 }
 
 GenTime AbstractClipItem::cropDuration() const
 {
-    return m_cropDuration;
+    return m_info.cropDuration;
 }
 
 void AbstractClipItem::setCropStart(GenTime pos)
 {
-    m_cropStart = pos;
+    m_info.cropStart = pos;
 }
 
 void AbstractClipItem::updateItem()
 {
-    m_track = (int)(scenePos().y() / KdenliveSettings::trackheight());
-    m_startPos = GenTime((int) scenePos().x(), m_fps);
+    m_info.track = (int)(scenePos().y() / KdenliveSettings::trackheight());
+    m_info.startPos = GenTime((int) scenePos().x(), m_fps);
 }
 
 void AbstractClipItem::updateRectGeometry()
@@ -90,32 +85,37 @@ void AbstractClipItem::updateRectGeometry()
     setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
 }
 
-void AbstractClipItem::resizeStart(int posx, double speed)
+void AbstractClipItem::resizeStart(int posx)
 {
-    GenTime durationDiff = GenTime(posx, m_fps) - m_startPos;
+    GenTime durationDiff = GenTime(posx, m_fps) - m_info.startPos;
     if (durationDiff == GenTime()) return;
     //kDebug() << "-- RESCALE DIFF=" << durationDiff.frames(25) << ", CLIP: " << startPos().frames(25) << "-" << endPos().frames(25);
 
     if (type() == AVWIDGET && cropStart() + durationDiff < GenTime()) {
         durationDiff = GenTime() - cropStart();
-    } else if (durationDiff >= m_cropDuration) {
+    } else if (durationDiff >= cropDuration()) {
         return;
-        if (m_cropDuration > GenTime(3, m_fps)) durationDiff = GenTime(3, m_fps);
+        if (cropDuration() > GenTime(3, m_fps)) durationDiff = GenTime(3, m_fps);
         else return;
     }
     //kDebug()<<"// DURATION DIFF: "<<durationDiff.frames(25)<<", POS: "<<pos().x();
-    m_startPos += durationDiff;
-    if (type() == AVWIDGET) m_cropStart += durationDiff * speed;
-    m_cropDuration = m_cropDuration - durationDiff * speed;
+    m_info.startPos += durationDiff;
 
+    if (type() == AVWIDGET) {
+        m_info.cropStart += durationDiff;
+    }
+    m_info.cropDuration = m_info.cropDuration - durationDiff;
     setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
     moveBy(durationDiff.frames(m_fps), 0);
     //setPos(m_startPos.frames(m_fps), pos().y());
     if ((int) scenePos().x() != posx) {
         //kDebug()<<"//////  WARNING, DIFF IN XPOS: "<<pos().x()<<" == "<<m_startPos.frames(m_fps);
         GenTime diff = GenTime((int) pos().x() - posx, m_fps);
-        if (type() == AVWIDGET) m_cropStart = m_cropStart + diff;
-        m_cropDuration = m_cropDuration - diff;
+
+        if (type() == AVWIDGET) {
+            m_info.cropStart += diff;
+        }
+        m_info.cropDuration = m_info.cropDuration - diff;
         setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
         //kDebug()<<"// NEW START: "<<m_startPos.frames(25)<<", NW DUR: "<<m_cropDuration.frames(25);
     }
@@ -142,16 +142,16 @@ void AbstractClipItem::resizeStart(int posx, double speed)
         }*/
 }
 
-void AbstractClipItem::resizeEnd(int posx, double speed, bool /*updateKeyFrames*/)
+void AbstractClipItem::resizeEnd(int posx)
 {
     GenTime durationDiff = GenTime(posx, m_fps) - endPos();
     if (durationDiff == GenTime()) return;
-    //kDebug() << "// DUR DIFF1:" << durationDiff.frames(25) << ", ADJUSTED: " << durationDiff.frames(25) * speed << ", SPED:" << speed;
     if (cropDuration() + durationDiff <= GenTime()) {
         durationDiff = GenTime() - (cropDuration() - GenTime(3, m_fps));
     }
-    //kDebug() << "// DUR DIFF2:" << durationDiff.frames(25) << ", ADJUSTED: " << durationDiff.frames(25) * speed << ", SPED:" << speed;
-    m_cropDuration += durationDiff * speed;
+
+    m_info.cropDuration += durationDiff;
+
     setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
     if (durationDiff > GenTime()) {
         QList <QGraphicsItem *> collisionList = collidingItems(Qt::IntersectsItemBoundingRect);
@@ -162,7 +162,7 @@ void AbstractClipItem::resizeEnd(int posx, double speed, bool /*updateKeyFrames*
                 kDebug() << "/////////  CURRENT: " << startPos().frames(25) << "x" << endPos().frames(25) << ", RECT: " << rect() << "-" << pos();
                 kDebug() << "/////////  COLLISION: " << ((AbstractClipItem *)item)->startPos().frames(25) << "x" << ((AbstractClipItem *)item)->endPos().frames(25) << ", RECT: " << ((AbstractClipItem *)item)->rect() << "-" << item->pos();*/
                 GenTime diff = ((AbstractClipItem *)item)->startPos() - GenTime(1, m_fps) - startPos();
-                m_cropDuration = diff * speed;
+                m_info.cropDuration = diff;
                 setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
                 break;
             }
@@ -172,12 +172,12 @@ void AbstractClipItem::resizeEnd(int posx, double speed, bool /*updateKeyFrames*
 
 GenTime AbstractClipItem::startPos() const
 {
-    return m_startPos;
+    return m_info.startPos;
 }
 
 void AbstractClipItem::setTrack(int track)
 {
-    m_track = track;
+    m_info.track = track;
 }
 
 double AbstractClipItem::fps() const
@@ -185,60 +185,18 @@ double AbstractClipItem::fps() const
     return m_fps;
 }
 
+void AbstractClipItem::updateFps(double fps)
+{
+    m_fps = fps;
+    setPos((qreal) startPos().frames(m_fps), pos().y());
+    updateRectGeometry();
+}
+
 GenTime AbstractClipItem::maxDuration() const
 {
     return m_maxDuration;
 }
 
-QPainterPath AbstractClipItem::upperRectPart(QRectF br)
-{
-    QPainterPath roundRectPathUpper;
-    double roundingY = 20;
-    double roundingX = 20;
-    double offset = 1;
-
-    while (roundingX > br.width() / 2) {
-        roundingX = roundingX / 2;
-        roundingY = roundingY / 2;
-    }
-    int br_endx = (int)(br.x() + br .width() - offset);
-    int br_startx = (int)(br.x() + offset);
-    int br_starty = (int)(br.y());
-    int br_halfy = (int)(br.y() + br.height() / 2 - offset);
-
-    roundRectPathUpper.moveTo(br_endx  , br_halfy);
-    roundRectPathUpper.arcTo(br_endx - roundingX , br_starty , roundingX, roundingY, 0.0, 90.0);
-    roundRectPathUpper.lineTo(br_startx + roundingX , br_starty);
-    roundRectPathUpper.arcTo(br_startx , br_starty , roundingX, roundingY, 90.0, 90.0);
-    roundRectPathUpper.lineTo(br_startx , br_halfy);
-
-    return roundRectPathUpper;
-}
-
-QPainterPath AbstractClipItem::lowerRectPart(QRectF br)
-{
-    QPainterPath roundRectPathLower;
-    double roundingY = 20;
-    double roundingX = 20;
-    double offset = 1;
-
-    int br_endx = (int)(br.x() + br .width() - offset);
-    int br_startx = (int)(br.x() + offset);
-    int br_halfy = (int)(br.y() + br.height() / 2 - offset);
-    int br_endy = (int)(br.y() + br.height() - 1);
-
-    while (roundingX > br.width() / 2) {
-        roundingX = roundingX / 2;
-        roundingY = roundingY / 2;
-    }
-    roundRectPathLower.moveTo(br_startx, br_halfy);
-    roundRectPathLower.arcTo(br_startx , br_endy - roundingY , roundingX, roundingY, 180.0, 90.0);
-    roundRectPathLower.lineTo(br_endx - roundingX  , br_endy);
-    roundRectPathLower.arcTo(br_endx - roundingX , br_endy - roundingY, roundingX, roundingY, 270.0, 90.0);
-    roundRectPathLower.lineTo(br_endx  , br_halfy);
-    return roundRectPathLower;
-}
-
 void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
 {
     if (m_keyframes.count() < 2) return;
@@ -260,14 +218,13 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
         QLineF l2 = painter->matrix().map(l);
         painter->setPen(QColor(168, 168, 168, 180));
         painter->drawLine(l2);
-        l2.translate(0, 1);
         painter->setPen(QColor(108, 108, 108, 180));
-        painter->drawLine(l2);
+        painter->drawLine(l2.translated(0, 1));
         painter->setPen(QColor(Qt::white));
     }
 
     // draw keyframes
-    QMap<int, double>::const_iterator i = m_keyframes.constBegin();
+    QMap<int, int>::const_iterator i = m_keyframes.constBegin();
     QColor color(Qt::blue);
     x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
     y1 = br.bottom() - i.value() * maxh;
@@ -283,27 +240,31 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
         l2 = painter->matrix().map(l);
         painter->drawLine(l2);
         if (active) {
-            painter->fillRect(l2.x1() - 3, l2.y1() - 3, 6, 6, QBrush(color));
+            const QRectF frame(l2.x1() - 3, l2.y1() - 3, 6, 6);
+            painter->fillRect(frame, color);
         }
         x1 = x2;
         y1 = y2;
     }
-    if (active) painter->fillRect(l2.x2() - 3, l2.y2() - 3, 6, 6, QBrush(color));
+    if (active) {
+        const QRectF frame(l2.x2() - 3, l2.y2() - 3, 6, 6);
+        painter->fillRect(frame, color);
+    }
 }
 
-int AbstractClipItem::mouseOverKeyFrames(QPointF pos)
+int AbstractClipItem::mouseOverKeyFrames(QPointF pos, double maxOffset)
 {
-    QRectF br = sceneBoundingRect();
+    const QRectF br = sceneBoundingRect();
     double maxw = br.width() / cropDuration().frames(m_fps);
     double maxh = br.height() / 100.0 * m_keyframeFactor;
     if (m_keyframes.count() > 1) {
-        QMap<int, double>::const_iterator i = m_keyframes.constBegin();
+        QMap<int, int>::const_iterator i = m_keyframes.constBegin();
         double x1;
         double y1;
         while (i != m_keyframes.constEnd()) {
             x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
             y1 = br.bottom() - i.value() * maxh;
-            if (qAbs(pos.x() - x1) < 6 && qAbs(pos.y() - y1) < 6) {
+            if (qAbs(pos.x() - x1) < maxOffset && qAbs(pos.y() - y1) < 10) {
                 setToolTip('[' + QString::number((GenTime(i.key(), m_fps) - cropStart()).seconds(), 'f', 2) + i18n("seconds") + ", " + QString::number(i.value(), 'f', 1) + "%]");
                 return i.key();
             } else if (x1 > pos.x()) break;
@@ -340,7 +301,7 @@ void AbstractClipItem::updateKeyFramePos(const GenTime pos, const double value)
     if (!m_keyframes.contains(m_selectedKeyframe)) return;
     int newpos = (int) pos.frames(m_fps);
     int start = cropStart().frames(m_fps);
-    int end = (cropStart() + cropDuration()).frames(m_fps);
+    int end = (cropStart() + cropDuration()).frames(m_fps) - 1;
     newpos = qMax(newpos, start);
     newpos = qMin(newpos, end);
     if (value < -50 && m_selectedKeyframe != start && m_selectedKeyframe != end) {
@@ -361,7 +322,7 @@ void AbstractClipItem::updateKeyFramePos(const GenTime pos, const double value)
     newval = qMin(newval, 100.0);
     newval = newval / m_keyframeFactor;
     if (m_selectedKeyframe != newpos) m_keyframes.remove(m_selectedKeyframe);
-    m_keyframes[newpos] = newval;
+    m_keyframes[newpos] = (int) newval;
     m_selectedKeyframe = newpos;
     update();
 }
@@ -375,8 +336,8 @@ void AbstractClipItem::addKeyFrame(const GenTime pos, const double value)
 {
     QRectF br = sceneBoundingRect();
     double maxh = 100.0 / br.height() / m_keyframeFactor;
-    double newval = (br.bottom() - value) * maxh;
-    kDebug() << "Rect: " << br << "/ SCENE: " << sceneBoundingRect() << ", VALUE: " << value << ", MAX: " << maxh << ", NEWVAL: " << newval;
+    int newval = (br.bottom() - value) * maxh;
+    //kDebug() << "Rect: " << br << "/ SCENE: " << sceneBoundingRect() << ", VALUE: " << value << ", MAX: " << maxh << ", NEWVAL: " << newval;
     int newpos = (int) pos.frames(m_fps) ;
     m_keyframes[newpos] = newval;
     m_selectedKeyframe = newpos;
