@@ -41,29 +41,29 @@ class ClipItem : public AbstractClipItem
     Q_OBJECT
 
 public:
-    ClipItem(DocClipBase *clip, ItemInfo info, double fps, double speed, bool generateThumbs = true);
+    ClipItem(DocClipBase *clip, ItemInfo info, double fps, double speed, int strobe, bool generateThumbs = true);
     virtual ~ ClipItem();
     virtual void paint(QPainter *painter,
                        const QStyleOptionGraphicsItem *option,
                        QWidget *);
     virtual int type() const;
-    void resizeStart(int posx, double speed = 1.0);
-    void resizeEnd(int posx, double speed = 1.0, bool updateKeyFrames = true);
+    void resizeStart(int posx);
+    void resizeEnd(int posx);
     OPERATIONTYPE operationMode(QPointF pos);
-    const QString &clipProducer() const;
+    const QString clipProducer() const;
     int clipType() const;
     DocClipBase *baseClip() const;
     QString clipName() const;
     void setClipName(const QString &name);
     QDomElement xml() const;
     ClipItem *clone(ItemInfo info) const;
-    const EffectsList effectList();
+    const EffectsList effectList() const;
     void setFadeOut(int pos);
     void setFadeIn(int pos);
     /** Give a string list of the clip's effect names */
     QStringList effectNames();
     /** Add an effect to the clip and return the parameters that will be passed to Mlt */
-    EffectsParameterList addEffect(QDomElement effect, bool animate = true);
+    EffectsParameterList addEffect(const QDomElement effect, bool animate = true);
     /** Get the effect parameters that will be passed to Mlt */
     EffectsParameterList getEffectArgs(QDomElement effect);
     /** Delete effect with id index */
@@ -72,8 +72,10 @@ public:
     int effectsCount();
     /** return a unique effect id */
     int effectsCounter();
+    /** return a copy of the xml of effect at index ix in stack */
+    QDomElement effectAt(int ix) const;
     /** return the xml of effect at index ix in stack */
-    QDomElement effectAt(int ix);
+    QDomElement getEffectAt(int ix) const;
     /** Replace effect at pos ix with given value */
     void setEffectAt(int ix, QDomElement effect);
     void flashClip();
@@ -91,16 +93,17 @@ public:
     void updateKeyframeEffect();
     QDomElement selectedEffect();
     int selectedEffectIndex() const;
-    void initEffect(QDomElement effect);
+    void initEffect(QDomElement effect, int diff = 0);
     QString keyframes(const int index);
     void setKeyframes(const int ix, const QString keyframes);
     void setEffectList(const EffectsList effectList);
-    void setSpeed(const double speed);
+    void setSpeed(const double speed, int strobe);
     double speed() const;
+    int strobe() const;
     GenTime maxDuration() const;
-    GenTime cropStart() const;
-    GenTime endPos() const;
-    GenTime cropDuration() const;
+    GenTime speedIndependantCropStart() const;
+    GenTime speedIndependantCropDuration() const;
+    const ItemInfo speedIndependantInfo() const;
     int hasEffect(const QString &tag, const QString &id) const;
     bool checkKeyFrames();
     QPixmap startThumb() const;
@@ -109,6 +112,8 @@ public:
     void setAudioOnly(bool force);
     bool isVideoOnly() const;
     bool isAudioOnly() const;
+    /** Called when clip start is resized, adjust keyframes values */
+    bool checkEffectsKeyframesPos(const int previous, const int current, bool fromStart);
 
 protected:
     //virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
@@ -121,6 +126,7 @@ protected:
 
 private:
     DocClipBase *m_clip;
+    ItemInfo m_speedIndependantInfo;
     QString m_producer;
     CLIPTYPE m_clipType;
     QString m_clipName;
@@ -129,12 +135,13 @@ private:
     int m_endFade;
     bool m_audioOnly;
     bool m_videoOnly;
+    QColor m_baseColor;
 
     QPixmap m_startPix;
     QPixmap m_endPix;
     bool m_hasThumbs;
-    QTimer *m_startThumbTimer;
-    QTimer *m_endThumbTimer;
+    QTimer m_startThumbTimer;
+    QTimer m_endThumbTimer;
 
     int m_selectedEffect;
     QTimeLine *m_timeLine;
@@ -142,14 +149,14 @@ private:
     bool m_endThumbRequested;
     //bool m_hover;
     double m_speed;
+    int m_strobe;
 
     EffectsList m_effectList;
     QList <Transition*> m_transitionsList;
     QMap<int, QPixmap> m_audioThumbCachePic;
     bool m_audioThumbReady;
     double m_framePixelWidth;
-    /** Called when clip start is resized, adjust keyframes values */
-    void checkEffectsKeyframesPos(const int previous, const int current, bool fromStart);
+
     QPixmap m_videoPix;
     QPixmap m_audioPix;
 
