@@ -43,10 +43,12 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
 {
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
+    connect(&m_fileWatcher, SIGNAL(dirty(const QString &)), this, SLOT(slotClipModified(const QString &)));
 }
 
 ClipManager::~ClipManager()
 {
+    kDebug() << "\n\n 2222222222222222222222222  CLOSE CM 22222222222";
     qDeleteAll(m_clipList);
 }
 
@@ -136,25 +138,38 @@ QMap <QString, QString> ClipManager::documentFolderList() const
 void ClipManager::addClip(DocClipBase *clip)
 {
     m_clipList.append(clip);
+    if (clip->clipType() == IMAGE || clip->clipType() == AUDIO || (clip->clipType() == TEXT && !clip->fileURL().isEmpty())) {
+        // listen for file change
+        m_fileWatcher.addFile(clip->fileURL().path());
+    }
     const QString id = clip->getId();
     if (id.toInt() >= m_clipIdCounter) m_clipIdCounter = id.toInt() + 1;
     const QString gid = clip->getProperty("groupid");
     if (!gid.isEmpty() && gid.toInt() >= m_folderIdCounter) m_folderIdCounter = gid.toInt() + 1;
 }
 
-void ClipManager::slotDeleteClip(const QString &clipId)
+void ClipManager::slotDeleteClips(QStringList ids)
 {
-    DocClipBase *clip = getClipById(clipId);
-    if (clip) {
-        AddClipCommand *command = new AddClipCommand(m_doc, clip->toXML(), clipId, false);
-        m_doc->commandStack()->push(command);
+    QUndoCommand *delClips = new QUndoCommand();
+    delClips->setText(i18np("Delete clip", "Delete clips", ids.size()));
+
+    for (int i = 0; i < ids.size(); i++) {
+        DocClipBase *clip = getClipById(ids.at(i));
+        if (clip) {
+            new AddClipCommand(m_doc, clip->toXML(), ids.at(i), false, delClips);
+        }
     }
+    m_doc->commandStack()->push(delClips);
 }
 
 void ClipManager::deleteClip(const QString &clipId)
 {
     for (int i = 0; i < m_clipList.count(); i++) {
         if (m_clipList.at(i)->getId() == clipId) {
+            if (m_clipList.at(i)->clipType() == IMAGE || m_clipList.at(i)->clipType() == AUDIO || (m_clipList.at(i)->clipType() == TEXT && !m_clipList.at(i)->fileURL().isEmpty())) {
+                // listen for file change
+                m_fileWatcher.removeFile(m_clipList.at(i)->fileURL().path());
+            }
             delete m_clipList.takeAt(i);
             break;
         }
@@ -179,17 +194,18 @@ DocClipBase *ClipManager::getClipById(QString clipId)
     return NULL;
 }
 
-DocClipBase *ClipManager::getClipByResource(QString resource)
+const QList <DocClipBase *> ClipManager::getClipByResource(QString resource)
 {
+    QList <DocClipBase *> list;
     QString clipResource;
     for (int i = 0; i < m_clipList.count(); i++) {
         clipResource = m_clipList.at(i)->getProperty("resource");
         if (clipResource.isEmpty()) clipResource = m_clipList.at(i)->getProperty("colour");
         if (clipResource == resource) {
-            return m_clipList.at(i);
+            list.append(m_clipList.at(i));
         }
     }
-    return NULL;
+    return list;
 }
 
 void ClipManager::updatePreviewSettings()
@@ -209,23 +225,31 @@ void ClipManager::updatePreviewSettings()
     }
 }
 
-void ClipManager::resetProducersList(QList <Mlt::Producer *> prods)
+void ClipManager::clearUnusedProducers()
+{
+    for (int i = 0; i < m_clipList.count(); i++) {
+        if (m_clipList.at(i)->numReferences() == 0) m_clipList.at(i)->deleteProducers();
+    }
+}
+
+void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods)
 {
     for (int i = 0; i < m_clipList.count(); i++) {
         if (m_clipList.at(i)->numReferences() > 0) {
-            m_clipList.at(i)->deleteProducers();
+            m_clipList.at(i)->clearProducers();
         }
     }
     QString id;
     for (int i = 0; i < prods.count(); i++) {
         id = prods.at(i)->get("id");
+        kDebug() << "// // // REPLACE CLIP: " << id;
         if (id.contains('_')) id = id.section('_', 0, 0);
         DocClipBase *clip = getClipById(id);
         if (clip) {
             clip->setProducer(prods.at(i));
-            kDebug() << "// // // REPLACE CLIP: " << id;
         }
     }
+    emit checkAllClips();
 }
 
 void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId)
@@ -248,8 +272,23 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
             KMimeType::Ptr type = KMimeType::findByUrl(file);
             if (type->name().startsWith("image/")) {
                 prod.setAttribute("type", (int) IMAGE);
-                prod.setAttribute("in", "0");
+                prod.setAttribute("in", 0);
                 prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+            } else if (type->name() == "application/x-kdenlivetitle") {
+                // opening a title file
+                QDomDocument txtdoc("titledocument");
+                QFile txtfile(file.path());
+                if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
+                    txtfile.close();
+                    prod.setAttribute("type", (int) TEXT);
+                    prod.setAttribute("resource", file.path());
+                    prod.setAttribute("xmldata", txtdoc.toString());
+                    prod.setAttribute("transparency", 1);
+                    prod.setAttribute("in", 0);
+                    int out = txtdoc.documentElement().attribute("out").toInt();
+                    if (out > 0) prod.setAttribute("out", out);
+                    else prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+                } else txtfile.close();
             }
             new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true, addClips);
         }
@@ -275,6 +314,22 @@ void ClipManager::slotAddClipFile(const KUrl url, const QString group, const QSt
         prod.setAttribute("type", (int) IMAGE);
         prod.setAttribute("in", "0");
         prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+    } else if (type->name() == "application/x-kdenlivetitle") {
+        // opening a title file
+        QDomDocument txtdoc("titledocument");
+        QFile txtfile(url.path());
+        if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
+            txtfile.close();
+            prod.setAttribute("type", (int) TEXT);
+            prod.setAttribute("resource", QString());
+            prod.setAttribute("xmldata", txtdoc.toString());
+            GenTime outPos(txtdoc.documentElement().attribute("out").toDouble() / 1000.0);
+            prod.setAttribute("transparency", 1);
+            prod.setAttribute("in", 0);
+            int out = (int) outPos.frames(m_doc->fps());
+            if (out > 0) prod.setAttribute("out", out);
+            else prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+        } else txtfile.close();
     }
     AddClipCommand *command = new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true);
     m_doc->commandStack()->push(command);
@@ -329,12 +384,12 @@ void ClipManager::slotAddSlideshowClipFile(const QString name, const QString pat
 
 
 
-void ClipManager::slotAddTextClipFile(const QString titleName, const QString imagePath, const QString xml, const QString group, const QString &groupId)
+void ClipManager::slotAddTextClipFile(const QString titleName, int out, const QString xml, const QString group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
     doc.appendChild(prod);
-    prod.setAttribute("resource", imagePath);
+    //prod.setAttribute("resource", imagePath);
     prod.setAttribute("name", titleName);
     prod.setAttribute("xmldata", xml);
     uint id = m_clipIdCounter++;
@@ -346,19 +401,18 @@ void ClipManager::slotAddTextClipFile(const QString titleName, const QString ima
     prod.setAttribute("type", (int) TEXT);
     prod.setAttribute("transparency", "1");
     prod.setAttribute("in", "0");
-    prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+    prod.setAttribute("out", out);
     AddClipCommand *command = new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true);
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddTextTemplateClip(QString titleName, const QString imagePath, const KUrl path, const QString group, const QString &groupId)
+void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl path, const QString group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
     doc.appendChild(prod);
-    prod.setAttribute("resource", imagePath);
     prod.setAttribute("name", titleName);
-    prod.setAttribute("xmltemplate", path.path());
+    prod.setAttribute("resource", path.path());
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
     if (!group.isEmpty()) {
@@ -368,7 +422,18 @@ void ClipManager::slotAddTextTemplateClip(QString titleName, const QString image
     prod.setAttribute("type", (int) TEXT);
     prod.setAttribute("transparency", "1");
     prod.setAttribute("in", "0");
-    prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+
+    int out = 0;
+    QDomDocument titledoc;
+    QFile txtfile(path.path());
+    if (txtfile.open(QIODevice::ReadOnly) && titledoc.setContent(&txtfile)) {
+        txtfile.close();
+        out = titledoc.documentElement().attribute("out").toInt();
+    } else txtfile.close();
+
+    if (out == 0) out = m_doc->getFramePos(KdenliveSettings::image_duration()) - 1;
+    prod.setAttribute("out", out);
+
     AddClipCommand *command = new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true);
     m_doc->commandStack()->push(command);
 }
@@ -444,3 +509,21 @@ QDomElement ClipManager::groupsXml() const
     }
     return doc.documentElement();
 }
+
+
+void ClipManager::slotClipModified(const QString &path)
+{
+    //kDebug()<<"// CLIP: "<<path<<" WAS MODIFIED";
+    const QList <DocClipBase *> list = getClipByResource(path);
+    for (int i = 0; i < list.count(); i++) {
+        DocClipBase *clip = list.at(i);
+        if (clip != NULL) emit reloadClip(clip->getId());
+    }
+}
+
+int ClipManager::clipsCount() const
+{
+    return m_clipList.count();
+}
+
+
