@@ -49,7 +49,8 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_tc(tc),
         m_fps(fps),
         m_count(0),
-        m_clipNeedsRefresh(false)
+        m_clipNeedsRefresh(false),
+        m_clipNeedsReLoad(false)
 {
     setFont(KGlobalSettings::toolBarFont());
     m_view.setupUi(this);
@@ -130,6 +131,9 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.image_size->setText(props.value("frame_size"));
         if (props.contains("transparency"))
             m_view.image_transparency->setChecked(props.value("transparency").toInt());
+        int width = 180.0 * KdenliveSettings::project_display_ratio();
+        if (width % 2 == 1) width++;
+        m_view.clip_thumb->setPixmap(QPixmap(url.path()).scaled(QSize(width, 180), Qt::KeepAspectRatio));
     } else if (t == COLOR) {
         m_view.clip_path->setEnabled(false);
         m_view.tabWidget->removeTab(METATAB);
@@ -231,7 +235,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
 
     KFileItem f(KFileItem::Unknown, KFileItem::Unknown, url, true);
     m_view.clip_filesize->setText(KIO::convertSize(f.size()));
-    m_view.clip_duration->setText(tc.getTimecode(m_clip->duration(), m_fps));
+    m_view.clip_duration->setText(tc.getTimecode(m_clip->duration()));
     if (t != IMAGE && t != COLOR && t != TEXT) m_view.clip_duration->setReadOnly(true);
     else connect(m_view.clip_duration, SIGNAL(editingFinished()), this, SLOT(slotCheckMaxLength()));
 
@@ -280,7 +284,7 @@ void ClipProperties::slotFillMarkersList()
     m_view.markers_list->clear();
     QList < CommentedTime > marks = m_clip->commentedSnapMarkers();
     for (int count = 0; count < marks.count(); ++count) {
-        QString time = m_tc.getTimecode(marks[count].time(), m_tc.fps());
+        QString time = m_tc.getTimecode(marks[count].time());
         QStringList itemtext;
         itemtext << time << marks[count].comment();
         (void) new QTreeWidgetItem(m_view.markers_list, itemtext);
@@ -378,16 +382,16 @@ QMap <QString, QString> ClipProperties::properties()
             m_clipNeedsRefresh = true;
             props["colour"] = "0x" + new_color.right(6) + "ff";
         }
-        int duration = m_tc.getFrameCount(m_view.clip_duration->text(), m_fps);
+        int duration = m_tc.getFrameCount(m_view.clip_duration->text());
         if (duration != m_clip->duration().frames(m_fps)) {
             props["out"] = QString::number(duration);
         }
     } else if (t == IMAGE) {
         if ((int) m_view.image_transparency->isChecked() != old_props.value("transparency").toInt()) {
             props["transparency"] = QString::number((int)m_view.image_transparency->isChecked());
-            m_clipNeedsRefresh = true;
+            //m_clipNeedsRefresh = true;
         }
-        int duration = m_tc.getFrameCount(m_view.clip_duration->text(), m_fps);
+        int duration = m_tc.getFrameCount(m_view.clip_duration->text());
         if (duration != m_clip->duration().frames(m_fps)) {
             props["out"] = QString::number(duration);
         }
@@ -416,7 +420,7 @@ QMap <QString, QString> ClipProperties::properties()
         }
         QString new_path = m_view.clip_path->text() + extension;
         if (new_path != old_props.value("resource")) {
-            m_clipNeedsRefresh = true;
+            m_clipNeedsReLoad = true;
             props["resource"] = new_path;
             kDebug() << "////  SLIDE EDIT, NEW:" << new_path << ", OLD; " << old_props.value("resource");
         }
@@ -424,7 +428,7 @@ QMap <QString, QString> ClipProperties::properties()
         if (m_view.slide_duration_format->currentIndex() == 1) {
             // we are in frames mode
             duration = m_view.slide_duration_frames->value();
-        } else duration = m_tc.getFrameCount(m_view.slide_duration->text(), m_fps);
+        } else duration = m_tc.getFrameCount(m_view.slide_duration->text());
         if (duration != old_props.value("ttl").toInt()) {
             m_clipNeedsRefresh = true;
             props["ttl"] = QString::number(duration);
@@ -439,7 +443,7 @@ QMap <QString, QString> ClipProperties::properties()
             if (m_view.slide_duration_format->currentIndex() == 1) {
                 // we are in frames mode
                 luma_duration = m_view.luma_duration_frames->value();
-            } else luma_duration = m_tc.getFrameCount(m_view.luma_duration->text(), m_fps);
+            } else luma_duration = m_tc.getFrameCount(m_view.luma_duration->text());
             if (luma_duration != old_props.value("luma_duration").toInt()) {
                 m_clipNeedsRefresh = true;
                 props["luma_duration"] = QString::number(luma_duration);
@@ -466,6 +470,11 @@ bool ClipProperties::needsTimelineRefresh() const
     return m_clipNeedsRefresh;
 }
 
+bool ClipProperties::needsTimelineReload() const
+{
+    return m_clipNeedsReLoad;
+}
+
 void ClipProperties::parseFolder()
 {
 
@@ -496,10 +505,12 @@ void ClipProperties::parseFolder()
     dir.setNameFilters(filters);
     QStringList result = dir.entryList(QDir::Files);
     m_count = result.count();
-    m_view.slide_info->setText(i18n("%1 images found", m_count));
+    m_view.slide_info->setText(i18np("1 image found", "%1 images found", m_count));
     QDomElement xml = m_clip->toXML();
     xml.setAttribute("resource", m_view.clip_path->text() + extension);
-    QPixmap pix = m_clip->thumbProducer()->getImage(KUrl(m_view.clip_path->text() + extension), 1, 240, 180);
+    int width = 180.0 * KdenliveSettings::project_display_ratio();
+    if (width % 2 == 1) width++;
+    QPixmap pix = m_clip->thumbProducer()->getImage(KUrl(m_view.clip_path->text() + extension), 1, width, 180);
     QMap <QString, QString> props = m_clip->properties();
     m_view.clip_duration->setText(m_tc.getTimecodeFromFrames(props.value("ttl").toInt() * m_count));
     m_view.clip_thumb->setPixmap(pix);
@@ -508,9 +519,9 @@ void ClipProperties::parseFolder()
 void ClipProperties::slotCheckMaxLength()
 {
     if (m_clip->maxDuration() == GenTime()) return;
-    int duration = m_tc.getFrameCount(m_view.clip_duration->text(), m_fps);
+    int duration = m_tc.getFrameCount(m_view.clip_duration->text());
     if (duration > m_clip->maxDuration().frames(m_fps)) {
-        m_view.clip_duration->setText(m_tc.getTimecode(m_clip->maxDuration(), m_fps));
+        m_view.clip_duration->setText(m_tc.getTimecode(m_clip->maxDuration()));
     }
 }
 
@@ -519,8 +530,8 @@ void ClipProperties::slotUpdateDurationFormat(int ix)
     bool framesFormat = ix == 1;
     if (framesFormat) {
         // switching to frames count, update widget
-        m_view.slide_duration_frames->setValue(m_tc.getFrameCount(m_view.slide_duration->text(), m_tc.fps()));
-        m_view.luma_duration_frames->setValue(m_tc.getFrameCount(m_view.luma_duration->text(), m_tc.fps()));
+        m_view.slide_duration_frames->setValue(m_tc.getFrameCount(m_view.slide_duration->text()));
+        m_view.luma_duration_frames->setValue(m_tc.getFrameCount(m_view.luma_duration->text()));
         m_view.slide_duration->setHidden(true);
         m_view.luma_duration->setHidden(true);
         m_view.slide_duration_frames->setHidden(false);
