@@ -26,6 +26,7 @@
 #include <QGraphicsTextItem>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsRectItem>
+#include <QDomElement>
 
 #include <KDebug>
 
@@ -56,44 +57,56 @@ class DvdButton : public QGraphicsTextItem
 {
 
 public:
-    DvdButton(const QString & text): QGraphicsTextItem(text), m_target(0) {}
+    DvdButton(const QString & text): QGraphicsTextItem(text), m_target(0), m_command(QString("jump title 1")), m_backToMenu(false) {}
     enum { Type = UserType + 1 };
-    void setTarget(int t) {
+    void setTarget(int t, QString c) {
         m_target = t;
+        m_command = c;
     }
     int target() const {
         return m_target;
     }
+    QString command() const {
+        return m_command;
+    }
+    bool backMenu() const {
+        return m_backToMenu;
+    }
     int type() const {
         // Enable the use of qgraphicsitem_cast with this item.
         return Type;
     }
+    void setBackMenu(bool back) {
+        m_backToMenu = back;
+    }
 
 private:
     int m_target;
-
+    QString m_command;
+    bool m_backToMenu;
 
 protected:
 
     virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value) {
         if (change == ItemPositionChange && scene()) {
 
-            /*   QList<QGraphicsItem *> list = collidingItems();
-               if (!list.isEmpty()) {
-                   for (int i = 0; i < list.count(); i++) {
-                if (list.at(i)->type() == Type) return pos();
-                   }
-               }
-            */
-            DvdScene *sc = static_cast < DvdScene * >(scene());
-            QRectF rect = QRectF(0, 0, sc->width(), sc->height());
             QPointF newPos = value.toPointF();
-            if (!rect.contains(newPos)) {
-                // Keep the item inside the scene rect.
-                newPos.setX(qMin(rect.right(), qMax(newPos.x(), rect.left())));
-                newPos.setY(qMin(rect.bottom(), qMax(newPos.y(), rect.top())));
-                return newPos;
+            QRectF sceneShape = sceneBoundingRect();
+            DvdScene *sc = static_cast < DvdScene * >(scene());
+            newPos.setX(qMax(newPos.x(), (qreal)0));
+            newPos.setY(qMax(newPos.y(), (qreal)0));
+            if (newPos.x() + sceneShape.width() > sc->width()) newPos.setX(sc->width() - sceneShape.width());
+            if (newPos.y() + sceneShape.height() > sc->height()) newPos.setY(sc->height() - sceneShape.height());
+
+            sceneShape.translate(newPos - pos());
+            QList<QGraphicsItem*> list = scene()->items(sceneShape, Qt::IntersectsItemShape);
+            list.removeAll(this);
+            if (!list.isEmpty()) {
+                for (int i = 0; i < list.count(); i++) {
+                    if (list.at(i)->type() == Type) return pos();
+                }
             }
+            return newPos;
         }
         return QGraphicsItem::itemChange(change, value);
     }
@@ -112,11 +125,14 @@ public:
     bool createMenu() const;
     void createBackgroundImage(const QString &img1);
     void createButtonImages(const QString &img1, const QString &img2, const QString &img3);
-    void setTargets(QStringList list);
-    QMap <int, QRect> buttonsInfo();
+    void setTargets(QStringList list, QStringList targetlist);
+    QMap <QString, QRect> buttonsInfo();
     bool menuMovie() const;
     QString menuMoviePath() const;
     bool isPalMenu() const;
+    void changeProfile(bool isPal);
+    QDomElement toXml() const;
+    void loadXml(QDomElement xml);
 
 private:
     Ui::DvdWizardMenu_UI m_view;
@@ -127,7 +143,6 @@ private:
     QGraphicsRectItem *m_safeRect;
     int m_width;
     int m_height;
-    QStringList m_targets;
 
 private slots:
     void buildButton();
@@ -135,7 +150,6 @@ private slots:
     void buildImage();
     void checkBackground();
     void checkBackgroundType(int ix);
-    void changeProfile(int ix);
     void updatePreview();
     void buttonChanged();
     void addButton();
@@ -143,6 +157,9 @@ private slots:
     void deleteButton();
     void updateColor();
     void updateColor(QColor c);
+    void setBackToMenu(bool backToMenu);
+    void slotZoom();
+    void slotUnZoom();
 };
 
 #endif
