@@ -22,9 +22,10 @@
 #include <KLocale>
 
 
-EffectsList::EffectsList() :
-        QList < QDomElement > ()
+EffectsList::EffectsList()
 {
+    m_baseElement = createElement("list");
+    appendChild(m_baseElement);
 }
 
 EffectsList::~EffectsList()
@@ -34,8 +35,9 @@ EffectsList::~EffectsList()
 QDomElement EffectsList::getEffectByName(const QString & name) const
 {
     QString effectName;
-    for (int i = 0; i < size(); ++i) {
-        QDomElement effect =  at(i);
+    QDomNodeList effects = m_baseElement.childNodes();
+    for (int i = 0; i < effects.count(); i++) {
+        QDomElement effect =  effects.at(i).toElement();
         QDomNode namenode = effect.elementsByTagName("name").item(0);
         if (!namenode.isNull()) effectName = i18n(namenode.toElement().text().toUtf8().data());
         if (name == effectName) {
@@ -54,10 +56,10 @@ QDomElement EffectsList::getEffectByName(const QString & name) const
 
 QDomElement EffectsList::getEffectByTag(const QString & tag, const QString & id) const
 {
-
-    if (!id.isEmpty()) for (int i = 0; i < size(); ++i) {
-            QDomElement effect =  at(i);
-            //kDebug() << "// SRCH EFFECT; " << id << ", LKING: " << effect.attribute("id");
+    QDomNodeList effects = m_baseElement.childNodes();
+    for (int i = 0; i < effects.count(); i++) {
+        QDomElement effect =  effects.at(i).toElement();
+        if (!id.isEmpty()) {
             if (effect.attribute("id") == id) {
                 QDomNodeList params = effect.elementsByTagName("parameter");
                 for (int i = 0; i < params.count(); i++) {
@@ -67,10 +69,7 @@ QDomElement EffectsList::getEffectByTag(const QString & tag, const QString & id)
                 }
                 return effect;
             }
-        }
-
-    if (!tag.isEmpty()) for (int i = 0; i < size(); ++i) {
-            QDomElement effect =  at(i);
+        } else if (!tag.isEmpty()) {
             if (effect.attribute("tag") == tag) {
                 QDomNodeList params = effect.elementsByTagName("parameter");
                 for (int i = 0; i < params.count(); i++) {
@@ -81,14 +80,15 @@ QDomElement EffectsList::getEffectByTag(const QString & tag, const QString & id)
                 return effect;
             }
         }
-
+    }
     return QDomElement();
 }
 
 int EffectsList::hasEffect(const QString & tag, const QString & id) const
 {
-    for (int i = 0; i < size(); ++i) {
-        QDomElement effect =  at(i);
+    QDomNodeList effects = m_baseElement.childNodes();
+    for (int i = 0; i < effects.count(); i++) {
+        QDomElement effect =  effects.at(i).toElement();
         if (!id.isEmpty()) {
             if (effect.attribute("id") == id) return i;
         } else if (!tag.isEmpty() && effect.attribute("tag") == tag) return i;
@@ -99,7 +99,7 @@ int EffectsList::hasEffect(const QString & tag, const QString & id) const
 QStringList EffectsList::effectIdInfo(const int ix) const
 {
     QStringList info;
-    QDomElement effect =  at(ix);
+    QDomElement effect = m_baseElement.childNodes().at(ix).toElement();
     QDomNode namenode = effect.elementsByTagName("name").item(0);
     info << i18n(namenode.toElement().text().toUtf8().data()) << effect.attribute("tag") << effect.attribute("id");
     return info;
@@ -108,8 +108,9 @@ QStringList EffectsList::effectIdInfo(const int ix) const
 QStringList EffectsList::effectNames()
 {
     QStringList list;
-    for (int i = 0; i < size(); ++i) {
-        QDomElement effect =  at(i);
+    QDomNodeList effects = m_baseElement.childNodes();
+    for (int i = 0; i < effects.count(); i++) {
+        QDomElement effect =  effects.at(i).toElement();
         QDomNode namenode = effect.elementsByTagName("name").item(0);
         if (!namenode.isNull()) list.append(i18n(namenode.toElement().text().toUtf8().data()));
     }
@@ -130,7 +131,7 @@ QString EffectsList::getInfo(const QString & tag, const QString & id) const
 QString EffectsList::getInfoFromIndex(const int ix) const
 {
     QString info;
-    QDomElement effect = at(ix);
+    QDomElement effect = m_baseElement.childNodes().at(ix).toElement();
     QDomNode namenode = effect.elementsByTagName("description").item(0);
     if (!namenode.isNull()) info = i18n(namenode.toElement().text().toUtf8().data());
     namenode = effect.elementsByTagName("author").item(0);
@@ -138,6 +139,7 @@ QString EffectsList::getInfoFromIndex(const int ix) const
     return info;
 }
 
+// static
 bool EffectsList::hasKeyFrames(QDomElement effect)
 {
     QDomNodeList params = effect.elementsByTagName("parameter");
@@ -148,13 +150,16 @@ bool EffectsList::hasKeyFrames(QDomElement effect)
     return false;
 }
 
-EffectsList EffectsList::clone() const
+void EffectsList::clone(const EffectsList original)
 {
-    EffectsList list;
-    for (int i = 0; i < size(); ++i) {
-        list.append(at(i).cloneNode().toElement());
-    }
-    return list;
+    setContent(original.toString());
+    m_baseElement = documentElement();
+}
+
+void EffectsList::clearList()
+{
+    while (!m_baseElement.firstChild().isNull())
+        m_baseElement.removeChild(m_baseElement.firstChild());
 }
 
 // static
@@ -183,3 +188,53 @@ QString EffectsList::parameter(QDomElement effect, const QString &name)
     return QString();
 }
 
+void EffectsList::append(QDomElement e)
+{
+    m_baseElement.appendChild(importNode(e, true));
+}
+
+int EffectsList::count() const
+{
+    return m_baseElement.childNodes().count();
+}
+
+bool EffectsList::isEmpty() const
+{
+    return m_baseElement.childNodes().count() == 0;
+}
+
+const QDomElement EffectsList::at(int ix) const
+{
+    QDomNodeList effects = m_baseElement.childNodes();
+    if (ix >= effects.count()) return QDomElement();
+    return effects.at(ix).toElement();
+}
+
+void EffectsList::removeAt(int ix)
+{
+    QDomNodeList effects = m_baseElement.childNodes();
+    if (ix >= effects.count()) return;
+    m_baseElement.removeChild(effects.at(ix));
+}
+
+QDomElement EffectsList::item(int ix)
+{
+    QDomNodeList effects = m_baseElement.childNodes();
+    if (ix >= effects.count()) return QDomElement();
+    return effects.at(ix).toElement();
+}
+
+void EffectsList::insert(int ix, QDomElement effect)
+{
+    QDomNodeList effects = m_baseElement.childNodes();
+    if (ix >= effects.count()) m_baseElement.appendChild(importNode(effect, true));
+    else m_baseElement.insertBefore(importNode(effect, true), effects.at(ix));
+}
+
+void EffectsList::replace(int ix, QDomElement effect)
+{
+    QDomNodeList effects = m_baseElement.childNodes();
+    if (ix < effects.count()) m_baseElement.removeChild(effects.at(ix));
+    if (ix == effects.count()) m_baseElement.appendChild(importNode(effect, true));
+    else m_baseElement.insertBefore(importNode(effect, true), effects.at(ix));
+}
