@@ -20,14 +20,15 @@
 #include "ui_listval_ui.h"
 #include "ui_boolval_ui.h"
 #include "ui_colorval_ui.h"
-#include "ui_positionval_ui.h"
 #include "ui_wipeval_ui.h"
 #include "ui_keyframeeditor_ui.h"
 #include "complexparameter.h"
 #include "geometryval.h"
 #include "keyframeedit.h"
+#include "positionedit.h"
 #include "effectslist.h"
 #include "kdenlivesettings.h"
+#include "profilesdialog.h"
 
 #include <KDebug>
 #include <KLocale>
@@ -40,27 +41,23 @@
 #include <QScrollArea>
 
 
-class Boolval: public EffectStackEdit::UiItem, public Ui::Boolval_UI
+class Boolval: public QWidget, public Ui::Boolval_UI
 {
 };
 
-class Colorval: public EffectStackEdit::UiItem, public Ui::Colorval_UI
+class Colorval: public QWidget, public Ui::Colorval_UI
 {
 };
 
-class Constval: public EffectStackEdit::UiItem, public Ui::Constval_UI
+class Constval: public QWidget, public Ui::Constval_UI
 {
 };
 
-class Listval: public EffectStackEdit::UiItem, public Ui::Listval_UI
+class Listval: public QWidget, public Ui::Listval_UI
 {
 };
 
-class Positionval: public EffectStackEdit::UiItem, public Ui::Positionval_UI
-{
-};
-
-class Wipeval: public EffectStackEdit::UiItem, public Ui::Wipeval_UI
+class Wipeval: public QWidget, public Ui::Wipeval_UI
 {
 };
 
@@ -68,32 +65,23 @@ class Wipeval: public EffectStackEdit::UiItem, public Ui::Wipeval_UI
 QMap<QString, QImage> EffectStackEdit::iconCache;
 
 EffectStackEdit::EffectStackEdit(QWidget *parent) :
-        QWidget(parent),
+        QScrollArea(parent),
         m_in(0),
         m_out(0),
         m_frameSize(QPoint())
 {
-    setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
-    QVBoxLayout *vbox1 = new QVBoxLayout(parent);
-    vbox1->setContentsMargins(0, 0, 0, 0);
-    vbox1->setSpacing(0);
+    m_baseWidget = new QWidget(this);
+    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+    setFrameStyle(QFrame::NoFrame);
+    setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding));
 
-    QScrollArea *area = new QScrollArea;
-    QWidget *wid = new QWidget(parent);
-    area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    area->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-    area->setFrameStyle(QFrame::NoFrame);
-    wid->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
-    area->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding));
-
-    vbox1->addWidget(area);
-    area->setWidget(wid);
-    area->setWidgetResizable(true);
-    m_vbox = new QVBoxLayout(wid);
+    setWidget(m_baseWidget);
+    setWidgetResizable(true);
+    m_vbox = new QVBoxLayout(m_baseWidget);
     m_vbox->setContentsMargins(0, 0, 0, 0);
     m_vbox->setSpacing(0);
-    wid->show();
-
+    //wid->show();
 }
 
 EffectStackEdit::~EffectStackEdit()
@@ -131,18 +119,21 @@ void EffectStackEdit::updateParameter(const QString &name, const QString &value)
     m_params.setAttribute(name, value);
 }
 
-void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
+void EffectStackEdit::transferParamDesc(const QDomElement d, int in, int out)
 {
-    kDebug() << "in";
+    clearAllItems();
     m_params = d;
     m_in = in;
     m_out = out;
-    clearAllItems();
-    if (m_params.isNull()) return;
+    if (m_params.isNull()) {
+        kDebug() << "// EMPTY EFFECT STACK";
+        return;
+    }
 
-    QDomDocument doc;
+    /*QDomDocument doc;
     doc.appendChild(doc.importNode(m_params, true));
-    //kDebug() << "IMPORTED TRANS: " << doc.toString();
+    kDebug() << "IMPORTED TRANS: " << doc.toString();*/
+
     QDomNodeList namenode = m_params.elementsByTagName("parameter");
     QDomElement e = m_params.toElement();
     const int minFrame = e.attribute("start").toInt();
@@ -150,14 +141,14 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
 
 
     for (int i = 0; i < namenode.count() ; i++) {
-        kDebug() << "in form";
         QDomElement pa = namenode.item(i).toElement();
         QDomNode na = pa.firstChildElement("name");
         QString type = pa.attribute("type");
         QString paramName = i18n(na.toElement().text().toUtf8().data());
-        QWidget * toFillin = new QWidget;
+        QWidget * toFillin = new QWidget(m_baseWidget);
         QString value = pa.attribute("value").isNull() ?
                         pa.attribute("default") : pa.attribute("value");
+
         if (type == "geometry") {
             /*pa.setAttribute("namedesc", "X;Y;Width;Height;Transparency");
             pa.setAttribute("format", "%d%,%d%:%d%x%d%:%d");
@@ -171,7 +162,15 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
 
         //TODO constant, list, bool, complex , color, geometry, position
         if (type == "double" || type == "constant") {
-            createSliderItem(paramName, value.toInt(), pa.attribute("min").toInt(), pa.attribute("max").toInt());
+            int min;
+            int max;
+            if (pa.attribute("min").startsWith('%')) {
+                min = (int) ProfilesDialog::getStringEval(m_profile, pa.attribute("min"));
+            } else min = pa.attribute("min").toInt();
+            if (pa.attribute("max").startsWith('%')) {
+                max = (int) ProfilesDialog::getStringEval(m_profile, pa.attribute("max"));
+            } else max = pa.attribute("max").toInt();
+            createSliderItem(paramName, (int)(value.toDouble() + 0.5) , min, max, pa.attribute("suffix", QString()));
             delete toFillin;
             toFillin = NULL;
         } else if (type == "list") {
@@ -194,19 +193,17 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
                 }
             }
             if (!value.isEmpty()) lsval->list->setCurrentIndex(listitems.indexOf(value));
-
-            connect(lsval->list, SIGNAL(currentIndexChanged(int)) , this, SLOT(collectAllParameters()));
             lsval->title->setTitle(paramName);
             m_valueItems[paramName] = lsval;
+            connect(lsval->list, SIGNAL(currentIndexChanged(int)) , this, SLOT(collectAllParameters()));
             m_uiItems.append(lsval);
         } else if (type == "bool") {
             Boolval *bval = new Boolval;
             bval->setupUi(toFillin);
             bval->checkBox->setCheckState(value == "0" ? Qt::Unchecked : Qt::Checked);
-
-            connect(bval->checkBox, SIGNAL(stateChanged(int)) , this, SLOT(collectAllParameters()));
             bval->checkBox->setText(paramName);
             m_valueItems[paramName] = bval;
+            connect(bval->checkBox, SIGNAL(stateChanged(int)) , this, SLOT(collectAllParameters()));
             m_uiItems.append(bval);
         } else if (type == "complex") {
             /*QStringList names=nodeAtts.namedItem("name").nodeValue().split(';');
@@ -223,30 +220,27 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
              };
             }*/
             ComplexParameter *pl = new ComplexParameter;
-            connect(pl, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
             pl->setupParam(d, pa.attribute("name"), 0, 100);
             m_vbox->addWidget(pl);
             m_valueItems[paramName+"complex"] = pl;
-            m_items.append(pl);
+            connect(pl, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
         } else if (type == "geometry") {
             Geometryval *geo = new Geometryval(m_profile, m_frameSize);
-            connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
-            connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
             geo->setupParam(pa, minFrame, maxFrame);
             m_vbox->addWidget(geo);
             m_valueItems[paramName+"geometry"] = geo;
-            m_items.append(geo);
+            connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
+            connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
         } else if (type == "keyframe") {
             // keyframe editor widget
             kDebug() << "min: " << m_in << ", MAX: " << m_out;
-            KeyframeEdit *geo = new KeyframeEdit(pa, m_out - m_in, m_timecode);
-            connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
+            KeyframeEdit *geo = new KeyframeEdit(pa, m_out - m_in - 1, pa.attribute("min").toInt(), pa.attribute("max").toInt(), m_timecode);
             //geo->setupParam(100, pa.attribute("min").toInt(), pa.attribute("max").toInt(), pa.attribute("keyframes"));
             //connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
             //geo->setupParam(pa, minFrame, maxFrame);
             m_vbox->addWidget(geo);
             m_valueItems[paramName+"keyframe"] = geo;
-            m_items.append(geo);
+            connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
         } else if (type == "color") {
             Colorval *cval = new Colorval;
             cval->setupUi(toFillin);
@@ -254,14 +248,11 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
             if (value.startsWith('#')) value = value.replace('#', "0x");
             cval->kcolorbutton->setColor(value.toUInt(&ok, 16));
             //kDebug() << "color: " << value << ", " << value.toUInt(&ok, 16);
-
-            connect(cval->kcolorbutton, SIGNAL(clicked()) , this, SLOT(collectAllParameters()));
             cval->label->setText(paramName);
             m_valueItems[paramName] = cval;
+            connect(cval->kcolorbutton, SIGNAL(clicked()) , this, SLOT(collectAllParameters()));
             m_uiItems.append(cval);
         } else if (type == "position") {
-            Positionval *pval = new Positionval;
-            pval->setupUi(toFillin);
             int pos = value.toInt();
             if (d.attribute("id") == "fadein" || d.attribute("id") == "fade_from_black") {
                 pos = pos - m_in;
@@ -269,11 +260,10 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
                 // fadeout position starts from clip end
                 pos = m_out - (pos - m_in);
             }
-            pval->krestrictedline->setText(m_timecode.getTimecodeFromFrames(pos));
-            connect(pval->krestrictedline, SIGNAL(editingFinished()), this, SLOT(collectAllParameters()));
-            pval->label->setText(paramName);
-            m_valueItems[paramName + "position"] = pval;
-            m_uiItems.append(pval);
+            PositionEdit *posedit = new PositionEdit(paramName, pos, 1, m_out, m_timecode);
+            m_vbox->addWidget(posedit);
+            m_valueItems[paramName+"position"] = posedit;
+            connect(posedit, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
         } else if (type == "wipe") {
             Wipeval *wpval = new Wipeval;
             wpval->setupUi(toFillin);
@@ -314,7 +304,7 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
             }
             wpval->start_transp->setValue(w.startTransparency);
             wpval->end_transp->setValue(w.endTransparency);
-
+            m_valueItems[paramName] = wpval;
             connect(wpval->end_up, SIGNAL(clicked()), this, SLOT(collectAllParameters()));
             connect(wpval->end_down, SIGNAL(clicked()), this, SLOT(collectAllParameters()));
             connect(wpval->end_left, SIGNAL(clicked()), this, SLOT(collectAllParameters()));
@@ -328,7 +318,6 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
             connect(wpval->start_transp, SIGNAL(valueChanged(int)), this, SLOT(collectAllParameters()));
             connect(wpval->end_transp, SIGNAL(valueChanged(int)), this, SLOT(collectAllParameters()));
             //wpval->title->setTitle(na.toElement().text());
-            m_valueItems[paramName] = wpval;
             m_uiItems.append(wpval);
         } else {
             delete toFillin;
@@ -336,7 +325,6 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
         }
 
         if (toFillin) {
-            m_items.append(toFillin);
             m_vbox->addWidget(toFillin);
         }
     }
@@ -418,59 +406,69 @@ QString EffectStackEdit::getWipeString(wipeInfo info)
 
 void EffectStackEdit::collectAllParameters()
 {
-    QDomElement oldparam = m_params.cloneNode().toElement();
-    QDomNodeList namenode = m_params.elementsByTagName("parameter");
+    if (m_valueItems.isEmpty() || m_params.isNull()) return;
+    const QDomElement oldparam = m_params.cloneNode().toElement();
+    QDomElement newparam = oldparam.cloneNode().toElement();
+    QDomNodeList namenode = newparam.elementsByTagName("parameter");
 
     for (int i = 0; i < namenode.count() ; i++) {
         QDomNode pa = namenode.item(i);
         QDomNode na = pa.firstChildElement("name");
         QString type = pa.attributes().namedItem("type").nodeValue();
         QString paramName = i18n(na.toElement().text().toUtf8().data());
+        if (type == "complex") paramName.append("complex");
+        else if (type == "position") paramName.append("position");
+        else if (type == "geometry") paramName.append("geometry");
+        else if (type == "keyframe") paramName.append("keyframe");
+        if (!m_valueItems.contains(paramName)) {
+            // kDebug() << "// Param: " << paramName << " NOT FOUND";
+            continue;
+        }
 
         QString setValue;
         if (type == "double" || type == "constant") {
-            QSlider* slider = ((Constval*)m_valueItems[paramName])->horizontalSlider;
+            QSlider* slider = ((Constval*)m_valueItems.value(paramName))->horizontalSlider;
             setValue = QString::number(slider->value());
         } else if (type == "list") {
-            KComboBox *box = ((Listval*)m_valueItems[paramName])->list;
+            KComboBox *box = ((Listval*)m_valueItems.value(paramName))->list;
             setValue = box->itemData(box->currentIndex()).toString();
         } else if (type == "bool") {
-            QCheckBox *box = ((Boolval*)m_valueItems[paramName])->checkBox;
+            QCheckBox *box = ((Boolval*)m_valueItems.value(paramName))->checkBox;
             setValue = box->checkState() == Qt::Checked ? "1" : "0" ;
         } else if (type == "color") {
-            KColorButton *color = ((Colorval*)m_valueItems[paramName])->kcolorbutton;
+            KColorButton *color = ((Colorval*)m_valueItems.value(paramName))->kcolorbutton;
             setValue = color->color().name();
         } else if (type == "complex") {
-            ComplexParameter *complex = ((ComplexParameter*)m_valueItems[paramName+"complex"]);
+            ComplexParameter *complex = ((ComplexParameter*)m_valueItems.value(paramName));
             namenode.item(i) = complex->getParamDesc();
         } else if (type == "geometry") {
-            Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
-            namenode.item(i) = geom->getParamDesc();
+            Geometryval *geom = ((Geometryval*)m_valueItems.value(paramName));
+            namenode.item(i).toElement().setAttribute("value", geom->getValue());
         } else if (type == "position") {
-            KRestrictedLine *line = ((Positionval*)m_valueItems[paramName+"position"])->krestrictedline;
-            int pos = m_timecode.getFrameCount(line->text(), KdenliveSettings::project_fps());
+            PositionEdit *pedit = ((PositionEdit*)m_valueItems.value(paramName));
+            int pos = pedit->getPosition();
             setValue = QString::number(pos);
-            if (m_params.attribute("id") == "fadein" || m_params.attribute("id") == "fade_from_black") {
+            if (newparam.attribute("id") == "fadein" || newparam.attribute("id") == "fade_from_black") {
                 // Make sure duration is not longer than clip
-                if (pos > m_out) {
+                /*if (pos > m_out) {
                     pos = m_out;
-                    line->setText(m_timecode.getTimecodeFromFrames(pos));
-                }
-                EffectsList::setParameter(m_params, "in", QString::number(m_in));
-                EffectsList::setParameter(m_params, "out", QString::number(m_in + pos));
+                    pedit->setPosition(pos);
+                }*/
+                EffectsList::setParameter(newparam, "in", QString::number(m_in));
+                EffectsList::setParameter(newparam, "out", QString::number(m_in + pos));
                 setValue.clear();
-            } else if (m_params.attribute("id") == "fadeout" || m_params.attribute("id") == "fade_to_black") {
+            } else if (newparam.attribute("id") == "fadeout" || newparam.attribute("id") == "fade_to_black") {
                 // Make sure duration is not longer than clip
-                if (pos > m_out) {
+                /*if (pos > m_out) {
                     pos = m_out;
-                    line->setText(m_timecode.getTimecodeFromFrames(pos));
-                }
-                EffectsList::setParameter(m_params, "in", QString::number(m_out + m_in - pos));
-                EffectsList::setParameter(m_params, "out", QString::number(m_out + m_in));
+                    pedit->setPosition(pos);
+                }*/
+                EffectsList::setParameter(newparam, "in", QString::number(m_out + m_in - pos));
+                EffectsList::setParameter(newparam, "out", QString::number(m_out + m_in));
                 setValue.clear();
             }
         } else if (type == "wipe") {
-            Wipeval *wp = (Wipeval*)m_valueItems[paramName];
+            Wipeval *wp = (Wipeval*)m_valueItems.value(paramName);
             wipeInfo info;
             if (wp->start_left->isChecked()) info.start = LEFT;
             else if (wp->start_right->isChecked()) info.start = RIGHT;
@@ -493,17 +491,17 @@ void EffectStackEdit::collectAllParameters()
             pa.attributes().namedItem("value").setNodeValue(setValue);
         }
     }
-    emit parameterChanged(oldparam, m_params);
+    emit parameterChanged(oldparam, newparam);
 }
 
-void EffectStackEdit::createSliderItem(const QString& name, int val , int min, int max)
+void EffectStackEdit::createSliderItem(const QString& name, int val , int min, int max, const QString suffix)
 {
-    QWidget* toFillin = new QWidget;
+    QWidget* toFillin = new QWidget(m_baseWidget);
     Constval *ctval = new Constval;
     ctval->setupUi(toFillin);
-
     ctval->horizontalSlider->setMinimum(min);
     ctval->horizontalSlider->setMaximum(max);
+    if (!suffix.isEmpty()) ctval->spinBox->setSuffix(suffix);
     ctval->spinBox->setMinimum(min);
     ctval->spinBox->setMaximum(max);
     ctval->horizontalSlider->setPageStep((int)(max - min) / 10);
@@ -512,7 +510,6 @@ void EffectStackEdit::createSliderItem(const QString& name, int val , int min, i
     m_valueItems[name] = ctval;
     m_uiItems.append(ctval);
     connect(ctval->horizontalSlider, SIGNAL(valueChanged(int)) , this, SLOT(collectAllParameters()));
-    m_items.append(toFillin);
     m_vbox->addWidget(toFillin);
 }
 
@@ -523,15 +520,20 @@ void EffectStackEdit::slotSliderMoved(int)
 
 void EffectStackEdit::clearAllItems()
 {
-    qDeleteAll(m_items);
-    qDeleteAll(m_uiItems);
-    m_uiItems.clear();
-    m_items.clear();
+    blockSignals(true);
     m_valueItems.clear();
-    QLayoutItem *item = m_vbox->itemAt(0);
-    while (item) {
-        m_vbox->removeItem(item);
-        delete item;
-        item = m_vbox->itemAt(0);
+    m_uiItems.clear();
+    /*while (!m_items.isEmpty()) {
+        QWidget *die = m_items.takeFirst();
+        die->disconnect();
+        delete die;
+    }*/
+    //qDeleteAll(m_uiItems);
+    QLayoutItem *child;
+    while ((child = m_vbox->takeAt(0)) != 0) {
+        QWidget *wid = child->widget();
+        delete child;
+        if (wid) delete wid;
     }
+    blockSignals(false);
 }
