@@ -18,14 +18,16 @@
 #ifndef EFFECTSTACKEDIT_H
 #define EFFECTSTACKEDIT_H
 
+#include "definitions.h"
+#include "timecode.h"
+
+
 #include <QWidget>
 #include <QDomElement>
 #include <QVBoxLayout>
 #include <QList>
 #include <QMap>
-
-#include "definitions.h"
-#include "timecode.h"
+#include <QScrollArea>
 
 enum WIPE_DIRECTON { UP = 0, DOWN = 1, LEFT = 2, RIGHT = 3, CENTER = 4 };
 
@@ -38,7 +40,7 @@ struct wipeInfo {
 
 class QFrame;
 
-class EffectStackEdit : public QWidget
+class EffectStackEdit : public QScrollArea
 {
     Q_OBJECT
 public:
@@ -49,21 +51,14 @@ public:
     void updateParameter(const QString &name, const QString &value);
     void setFrameSize(QPoint p);
 
-    class UiItem
-    {
-    public:
-        UiItem() {};
-        ~UiItem() {};
-    };
-
 private:
     void clearAllItems();
     QVBoxLayout *m_vbox;
-    QList<QWidget*> m_items;
-    QList<UiItem*> m_uiItems;
+    QList<QWidget*> m_uiItems;
+    QWidget *m_baseWidget;
     QDomElement m_params;
-    QMap<QString, void*> m_valueItems;
-    void createSliderItem(const QString& name, int val , int min, int max);
+    QMap<QString, QWidget*> m_valueItems;
+    void createSliderItem(const QString& name, int val , int min, int max, const QString);
     wipeInfo getWipeInfo(QString value);
     QString getWipeString(wipeInfo info);
     MltVideoProfile m_profile;
@@ -73,7 +68,7 @@ private:
     QPoint m_frameSize;
 
 public slots:
-    void transferParamDesc(const QDomElement&, int , int);
+    void transferParamDesc(const QDomElement, int , int);
     void slotSliderMoved(int);
     /** \brief Called whenever(?) some parameter is changed in the gui.
      *
@@ -84,7 +79,7 @@ private slots:
     void slotSeekToPos(int);
 
 signals:
-    void parameterChanged(const QDomElement&, const QDomElement&);
+    void parameterChanged(const QDomElement, const QDomElement);
     void seekTimeline(int);
 };
 
