@@ -31,6 +31,7 @@ class EffectStackView : public QWidget
 
 public:
     EffectStackView(QWidget *parent = 0);
+    virtual ~EffectStackView();
     void raiseWindow(QWidget*);
     void clear();
     void setMenu(QMenu *menu);
@@ -46,10 +47,10 @@ private:
 
 public slots:
     void slotClipItemSelected(ClipItem*, int ix);
-    void slotUpdateEffectParams(const QDomElement&, const QDomElement&);
+    void slotUpdateEffectParams(const QDomElement, const QDomElement);
 
 private slots:
-    void slotItemSelectionChanged();
+    void slotItemSelectionChanged(bool update = true);
     void slotItemUp();
     void slotItemDown();
     void slotItemDel();
@@ -58,7 +59,6 @@ private slots:
     void slotSaveEffect();
 
 signals:
-    void transferParamDesc(const QDomElement&, int , int);
     void removeEffect(ClipItem*, QDomElement);
     /**  Parameters for an effect changed, update the filter in playlist */
     void updateClipEffect(ClipItem*, QDomElement, QDomElement, int);
