@@ -37,48 +37,54 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, QWidg
         m_fixedMode(false),
         m_frameSize(frame_size)
 {
-    m_ui.setupUi(this);
-    QVBoxLayout* vbox = new QVBoxLayout(m_ui.widget);
+    setupUi(this);
+    QVBoxLayout* vbox = new QVBoxLayout(widget);
     QGraphicsView *view = new QGraphicsView(this);
     view->setBackgroundBrush(QBrush(Qt::black));
     vbox->addWidget(view);
     vbox->setContentsMargins(0, 0, 0, 0);
 
-    QVBoxLayout* vbox2 = new QVBoxLayout(m_ui.keyframeWidget);
+    QVBoxLayout* vbox2 = new QVBoxLayout(keyframeWidget);
     m_helper = new KeyframeHelper(this);
     vbox2->addWidget(m_helper);
     vbox2->setContentsMargins(0, 0, 0, 0);
 
     connect(m_helper, SIGNAL(positionChanged(int)), this, SLOT(slotPositionChanged(int)));
+    connect(m_helper, SIGNAL(keyframeMoved(int)), this, SLOT(slotKeyframeMoved(int)));
+    connect(m_helper, SIGNAL(addKeyframe(int)), this, SLOT(slotAddFrame(int)));
+    connect(m_helper, SIGNAL(removeKeyframe(int)), this, SLOT(slotDeleteFrame(int)));
 
     m_scene = new GraphicsSceneRectMove(this);
     m_scene->setTool(TITLE_SELECT);
     view->setScene(m_scene);
-    QGraphicsRectItem *m_frameBorder = new QGraphicsRectItem(QRectF(0, 0, profile.width, profile.height));
-    m_frameBorder->setZValue(-1100);
-    m_frameBorder->setBrush(QColor(255, 255, 0, 30));
-    m_frameBorder->setPen(QPen(QBrush(QColor(255, 255, 255, 255)), 1.0, Qt::DashLine));
-    m_scene->addItem(m_frameBorder);
+    m_dar = (m_profile.height * m_profile.display_aspect_num / (double) m_profile.display_aspect_den) / (double) m_profile.width;
 
-    m_ui.buttonNext->setIcon(KIcon("media-skip-forward"));
-    m_ui.buttonNext->setToolTip(i18n("Go to next keyframe"));
-    m_ui.buttonPrevious->setIcon(KIcon("media-skip-backward"));
-    m_ui.buttonPrevious->setToolTip(i18n("Go to previous keyframe"));
-    m_ui.buttonAdd->setIcon(KIcon("document-new"));
-    m_ui.buttonAdd->setToolTip(i18n("Add keyframe"));
-    m_ui.buttonDelete->setIcon(KIcon("edit-delete"));
-    m_ui.buttonDelete->setToolTip(i18n("Delete keyframe"));
+    m_realWidth = (int)(profile.height * profile.display_aspect_num / (double) profile.display_aspect_den);
+    QGraphicsRectItem *frameBorder = new QGraphicsRectItem(QRectF(0, 0, m_realWidth, profile.height));
+    frameBorder->setZValue(-1100);
+    frameBorder->setBrush(QColor(255, 255, 0, 30));
+    frameBorder->setPen(QPen(QBrush(QColor(255, 255, 255, 255)), 1.0, Qt::DashLine));
+    m_scene->addItem(frameBorder);
 
-    QMenu *configMenu = new QMenu(i18n("Misc..."), this);
-    m_ui.buttonMenu->setIcon(KIcon("system-run"));
-    m_ui.buttonMenu->setMenu(configMenu);
-    m_ui.buttonMenu->setPopupMode(QToolButton::QToolButton::InstantPopup);
+    buttonNext->setIcon(KIcon("media-skip-forward"));
+    buttonNext->setToolTip(i18n("Go to next keyframe"));
+    buttonPrevious->setIcon(KIcon("media-skip-backward"));
+    buttonPrevious->setToolTip(i18n("Go to previous keyframe"));
+    buttonAdd->setIcon(KIcon("document-new"));
+    buttonAdd->setToolTip(i18n("Add keyframe"));
+    buttonDelete->setIcon(KIcon("edit-delete"));
+    buttonDelete->setToolTip(i18n("Delete keyframe"));
+
+    m_configMenu = new QMenu(i18n("Misc..."), this);
+    buttonMenu->setIcon(KIcon("system-run"));
+    buttonMenu->setMenu(m_configMenu);
+    buttonMenu->setPopupMode(QToolButton::QToolButton::InstantPopup);
 
 
-    configMenu->addAction(i18n("Geometry"), this, SLOT(slotGeometry()));
+    m_editGeom = m_configMenu->addAction(i18n("Edit keyframe"), this, SLOT(slotGeometry()));
 
     m_scaleMenu = new QMenu(i18n("Resize..."), this);
-    configMenu->addMenu(m_scaleMenu);
+    m_configMenu->addMenu(m_scaleMenu);
     m_scaleMenu->addAction(i18n("50%"), this, SLOT(slotResize50()));
     m_scaleMenu->addAction(i18n("100%"), this, SLOT(slotResize100()));
     m_scaleMenu->addAction(i18n("200%"), this, SLOT(slotResize200()));
@@ -86,7 +92,7 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, QWidg
     m_scaleMenu->addAction(i18n("Custom"), this, SLOT(slotResizeCustom()));
 
     m_alignMenu = new QMenu(i18n("Align..."), this);
-    configMenu->addMenu(m_alignMenu);
+    m_configMenu->addMenu(m_alignMenu);
     m_alignMenu->addAction(i18n("Center"), this, SLOT(slotAlignCenter()));
     m_alignMenu->addAction(i18n("Hor. Center"), this, SLOT(slotAlignHCenter()));
     m_alignMenu->addAction(i18n("Vert. Center"), this, SLOT(slotAlignVCenter()));
@@ -96,7 +102,7 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, QWidg
     m_alignMenu->addAction(i18n("Bottom"), this, SLOT(slotAlignBottom()));
 
 
-    m_syncAction = configMenu->addAction(i18n("Sync timeline cursor"), this, SLOT(slotSyncCursor()));
+    m_syncAction = m_configMenu->addAction(i18n("Sync timeline cursor"), this, SLOT(slotSyncCursor()));
     m_syncAction->setCheckable(true);
     m_syncAction->setChecked(KdenliveSettings::transitionfollowcursor());
 
@@ -106,45 +112,62 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, QWidg
     QRectF srect = view->sceneRect();
     view->setSceneRect(srect.x(), -srect.height() / 3 + 10, srect.width(), srect.height() + srect.height() / 3 * 2 - 10);
     m_scene->setZoom(sc);
-    view->centerOn(m_frameBorder);
-    connect(m_ui.buttonNext , SIGNAL(clicked()) , this , SLOT(slotNextFrame()));
-    connect(m_ui.buttonPrevious , SIGNAL(clicked()) , this , SLOT(slotPreviousFrame()));
-    connect(m_ui.buttonDelete , SIGNAL(clicked()) , this , SLOT(slotDeleteFrame()));
-    connect(m_ui.buttonAdd , SIGNAL(clicked()) , this , SLOT(slotAddFrame()));
+    view->centerOn(frameBorder);
+    connect(buttonNext , SIGNAL(clicked()) , this , SLOT(slotNextFrame()));
+    connect(buttonPrevious , SIGNAL(clicked()) , this , SLOT(slotPreviousFrame()));
+    connect(buttonDelete , SIGNAL(clicked()) , this , SLOT(slotDeleteFrame()));
+    connect(buttonAdd , SIGNAL(clicked()) , this , SLOT(slotAddFrame()));
     connect(m_scene, SIGNAL(actionFinished()), this, SLOT(slotUpdateTransitionProperties()));
     connect(m_scene, SIGNAL(doubleClickEvent()), this, SLOT(slotGeometry()));
 
 }
 
+
+Geometryval::~Geometryval()
+{
+    m_scene->disconnect();
+    delete m_scaleMenu;
+    delete m_alignMenu;
+    delete m_editGeom;
+    delete m_syncAction;
+    delete m_configMenu;
+    delete m_paramRect;
+    delete m_path;
+    delete m_helper;
+    delete m_geom;
+    delete m_scene;
+}
+
+
 void Geometryval::slotAlignCenter()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setPos((m_profile.width - m_paramRect->rect().width()) / 2, (m_profile.height - m_paramRect->rect().height()) / 2);
+    m_paramRect->setPos((m_realWidth - m_paramRect->rect().width()) / 2, (m_profile.height - m_paramRect->rect().height()) / 2);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignHCenter()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setPos((m_profile.width - m_paramRect->rect().width()) / 2, m_paramRect->pos().y());
+    m_paramRect->setPos((m_realWidth - m_paramRect->rect().width()) / 2, m_paramRect->pos().y());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignVCenter()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -157,7 +180,7 @@ void Geometryval::slotAlignVCenter()
 
 void Geometryval::slotAlignTop()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -170,7 +193,7 @@ void Geometryval::slotAlignTop()
 
 void Geometryval::slotAlignBottom()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -183,7 +206,7 @@ void Geometryval::slotAlignBottom()
 
 void Geometryval::slotAlignLeft()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -196,60 +219,60 @@ void Geometryval::slotAlignLeft()
 
 void Geometryval::slotAlignRight()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setPos(m_profile.width - m_paramRect->rect().width(), m_paramRect->pos().y());
+    m_paramRect->setPos(m_realWidth - m_paramRect->rect().width(), m_paramRect->pos().y());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotResize50()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setRect(0, 0, m_profile.width / 2, m_profile.height / 2);
+    m_paramRect->setRect(0, 0, m_realWidth / 2, m_profile.height / 2);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotResize100()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setRect(0, 0, m_profile.width, m_profile.height);
+    m_paramRect->setRect(0, 0, m_realWidth, m_profile.height);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotResize200()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    m_paramRect->setRect(0, 0, m_profile.width * 2, m_profile.height * 2);
+    m_paramRect->setRect(0, 0, m_realWidth * 2, m_profile.height * 2);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotResizeOriginal()
 {
     if (m_frameSize.isNull()) slotResize100();
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -262,24 +285,24 @@ void Geometryval::slotResizeOriginal()
 
 void Geometryval::slotResizeCustom()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor
         return;
     }
-    int scale = m_paramRect->rect().width() * 100 / m_profile.width;
+    int scale = m_paramRect->rect().width() * 100 / m_realWidth;
     bool ok;
     scale =  QInputDialog::getInteger(this, i18n("Resize..."), i18n("Scale"), scale, 1, 2147483647, 10, &ok);
     if (!ok) return;
-    m_paramRect->setRect(0, 0, m_profile.width * scale / 100, m_profile.height * scale / 100);
+    m_paramRect->setRect(0, 0, m_realWidth * scale / 100, m_profile.height * scale / 100);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotTransparencyChanged(int transp)
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -300,73 +323,80 @@ void Geometryval::slotSyncCursor()
 void Geometryval::slotPositionChanged(int pos, bool seek)
 {
     if (seek && KdenliveSettings::transitionfollowcursor()) emit seekToPos(pos);
-    m_ui.spinPos->setValue(pos);
+    spinPos->setValue(pos);
     m_helper->setValue(pos);
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
         // no keyframe under cursor, adjust buttons
-        m_ui.buttonAdd->setEnabled(true);
-        m_ui.buttonDelete->setEnabled(false);
-        m_ui.widget->setEnabled(false);
-        m_ui.spinTransp->setEnabled(false);
+        buttonAdd->setEnabled(true);
+        buttonDelete->setEnabled(false);
+        widget->setEnabled(false);
+        spinTransp->setEnabled(false);
         m_scaleMenu->setEnabled(false);
         m_alignMenu->setEnabled(false);
+        m_editGeom->setEnabled(false);
     } else {
-        m_ui.buttonAdd->setEnabled(false);
-        m_ui.buttonDelete->setEnabled(true);
-        m_ui.widget->setEnabled(true);
-        m_ui.spinTransp->setEnabled(true);
+        buttonAdd->setEnabled(false);
+        buttonDelete->setEnabled(true);
+        widget->setEnabled(true);
+        spinTransp->setEnabled(true);
         m_scaleMenu->setEnabled(true);
         m_alignMenu->setEnabled(true);
+        m_editGeom->setEnabled(true);
     }
-    m_paramRect->setPos(item.x(), item.y());
-    m_paramRect->setRect(0, 0, item.w(), item.h());
-    m_ui.spinTransp->setValue(item.mix());
+
+    m_paramRect->setPos(item.x() * m_dar, item.y());
+    m_paramRect->setRect(0, 0, item.w() * m_dar, item.h());
+    spinTransp->setValue(item.mix());
     m_paramRect->setBrush(QColor(255, 0, 0, item.mix()));
 }
 
-void Geometryval::slotDeleteFrame()
+void Geometryval::slotDeleteFrame(int pos)
 {
     // check there is more than one keyframe
     Mlt::GeometryItem item;
-    const int pos = m_ui.spinPos->value();
+    if (pos == -1) pos = spinPos->value();
     int error = m_geom->next_key(&item, pos + 1);
     if (error) {
         error = m_geom->prev_key(&item, pos - 1);
         if (error || item.frame() == pos) return;
     }
 
-    m_geom->remove(m_ui.spinPos->value());
-    m_ui.buttonAdd->setEnabled(true);
-    m_ui.buttonDelete->setEnabled(false);
-    m_ui.widget->setEnabled(false);
-    m_ui.spinTransp->setEnabled(false);
+    m_geom->remove(spinPos->value());
+    buttonAdd->setEnabled(true);
+    buttonDelete->setEnabled(false);
+    widget->setEnabled(false);
+    spinTransp->setEnabled(false);
     m_scaleMenu->setEnabled(false);
     m_alignMenu->setEnabled(false);
+    m_editGeom->setEnabled(false);
     m_helper->update();
     slotPositionChanged(pos, false);
     updateTransitionPath();
     emit parameterChanged();
 }
 
-void Geometryval::slotAddFrame()
+void Geometryval::slotAddFrame(int pos)
 {
-    int pos = m_ui.spinPos->value();
+    if (pos == -1) pos = spinPos->value();
     Mlt::GeometryItem item;
     item.frame(pos);
-    item.x(m_paramRect->pos().x());
-    item.y(m_paramRect->pos().y());
-    item.w(m_paramRect->rect().width());
-    item.h(m_paramRect->rect().height());
-    item.mix(m_ui.spinTransp->value());
+    QRectF r = m_paramRect->rect().normalized();
+    QPointF rectpos = m_paramRect->pos();
+    item.x(rectpos.x() / m_dar);
+    item.y(rectpos.y());
+    item.w(r.width() / m_dar);
+    item.h(r.height());
+    item.mix(spinTransp->value());
     m_geom->insert(item);
-    m_ui.buttonAdd->setEnabled(false);
-    m_ui.buttonDelete->setEnabled(true);
-    m_ui.widget->setEnabled(true);
-    m_ui.spinTransp->setEnabled(true);
+    buttonAdd->setEnabled(false);
+    buttonDelete->setEnabled(true);
+    widget->setEnabled(true);
+    spinTransp->setEnabled(true);
     m_scaleMenu->setEnabled(true);
     m_alignMenu->setEnabled(true);
+    m_editGeom->setEnabled(true);
     m_helper->update();
     emit parameterChanged();
 }
@@ -378,11 +408,11 @@ void Geometryval::slotNextFrame()
     kDebug() << "// SEEK TO NEXT KFR: " << error;
     if (error) {
         // Go to end
-        m_ui.spinPos->setValue(m_ui.spinPos->maximum());
+        spinPos->setValue(spinPos->maximum());
         return;
     }
     int pos = item.frame();
-    m_ui.spinPos->setValue(pos);
+    spinPos->setValue(pos);
 }
 
 void Geometryval::slotPreviousFrame()
@@ -392,31 +422,29 @@ void Geometryval::slotPreviousFrame()
     kDebug() << "// SEEK TO NEXT KFR: " << error;
     if (error) return;
     int pos = item.frame();
-    m_ui.spinPos->setValue(pos);
+    spinPos->setValue(pos);
 }
 
 
-QDomElement Geometryval::getParamDesc()
+QString Geometryval::getValue() const
 {
-    m_param.setAttribute("value", m_geom->serialise());
-    kDebug() << " / / UPDATING TRANSITION VALUE: " << m_param.attribute("value");
-    return m_param;
+    return m_geom->serialise();
 }
 
-void Geometryval::setupParam(const QDomElement& par, int minFrame, int maxFrame)
+void Geometryval::setupParam(const QDomElement par, int minFrame, int maxFrame)
 {
-    m_param = par;
     QString val = par.attribute("value");
     if (par.attribute("fixed") == "1") {
         m_fixedMode = true;
-        m_ui.buttonPrevious->setHidden(true);
-        m_ui.buttonNext->setHidden(true);
-        m_ui.buttonDelete->setHidden(true);
-        m_ui.buttonAdd->setHidden(true);
-        m_ui.spinTransp->setMaximum(500);
-        m_ui.label_pos->setHidden(true);
+        buttonPrevious->setHidden(true);
+        buttonNext->setHidden(true);
+        buttonDelete->setHidden(true);
+        buttonAdd->setHidden(true);
+        spinTransp->setMaximum(500);
+        label_pos->setHidden(true);
         m_helper->setHidden(true);
-        m_ui.spinPos->setHidden(true);
+        spinPos->setHidden(true);
+
     }
     char *tmp = (char *) qstrdup(val.toUtf8().data());
     if (m_geom) m_geom->parse(tmp, maxFrame - minFrame, m_profile.width, m_profile.height);
@@ -431,7 +459,7 @@ void Geometryval::setupParam(const QDomElement& par, int minFrame, int maxFrame)
         /*QDomDocument doc;
         doc.appendChild(doc.importNode(par, true));
         kDebug() << "IMPORTED TRANS: " << doc.toString();*/
-        m_ui.spinPos->setMaximum(maxFrame - minFrame - 1);
+        spinPos->setMaximum(maxFrame - minFrame - 1);
         if (m_path == NULL) {
             m_path = new QGraphicsPathItem();
             m_path->setPen(QPen(Qt::red));
@@ -443,17 +471,18 @@ void Geometryval::setupParam(const QDomElement& par, int minFrame, int maxFrame)
 
     m_geom->fetch(&item, 0);
     delete m_paramRect;
-    m_paramRect = new QGraphicsRectItem(QRectF(0, 0, item.w(), item.h()));
-    m_paramRect->setPos(item.x(), item.y());
+    m_paramRect = new QGraphicsRectItem(QRectF(0, 0, item.w() * m_dar, item.h()));
+    m_paramRect->setPos(item.x() * m_dar, item.y());
     m_paramRect->setZValue(0);
+    m_paramRect->setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
 
     m_paramRect->setPen(QPen(QBrush(QColor(255, 0, 0, 255)), 1.0));
     m_scene->addItem(m_paramRect);
     slotPositionChanged(0, false);
     if (!m_fixedMode) {
-        connect(m_ui.spinPos, SIGNAL(valueChanged(int)), this , SLOT(slotPositionChanged(int)));
+        connect(spinPos, SIGNAL(valueChanged(int)), this , SLOT(slotPositionChanged(int)));
     }
-    connect(m_ui.spinTransp, SIGNAL(valueChanged(int)), this , SLOT(slotTransparencyChanged(int)));
+    connect(spinTransp, SIGNAL(valueChanged(int)), this , SLOT(slotTransparencyChanged(int)));
 }
 
 void Geometryval::updateTransitionPath()
@@ -467,9 +496,9 @@ void Geometryval::updateTransitionPath()
         if (m_geom->next_key(&item, pos) == 1) break;
         pos = item.frame();
         if (counter == 0) {
-            path.moveTo(item.x() + item.w() / 2, item.y() + item.h() / 2);
+            path.moveTo(item.x() * m_dar + item.w() * m_dar / 2, item.y() + item.h() / 2);
         } else {
-            path.lineTo(item.x() + item.w() / 2, item.y() + item.h() / 2);
+            path.lineTo(item.x() * m_dar + item.w() * m_dar / 2, item.y() + item.h() / 2);
         }
         counter++;
         pos++;
@@ -479,7 +508,7 @@ void Geometryval::updateTransitionPath()
 
 void Geometryval::slotUpdateTransitionProperties()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->next_key(&item, pos);
     if (error || item.frame() != pos) {
@@ -487,9 +516,10 @@ void Geometryval::slotUpdateTransitionProperties()
         return;
     }
     QRectF r = m_paramRect->rect().normalized();
-    item.x(m_paramRect->pos().x());
-    item.y(m_paramRect->pos().y());
-    item.w(r.width());
+    QPointF rectpos = m_paramRect->pos();
+    item.x(rectpos.x() / m_dar);
+    item.y(rectpos.y());
+    item.w(r.width() / m_dar);
     item.h(r.height());
     m_geom->insert(item);
     updateTransitionPath();
@@ -498,7 +528,7 @@ void Geometryval::slotUpdateTransitionProperties()
 
 void Geometryval::slotGeometry()
 {
-    int pos = m_ui.spinPos->value();
+    int pos = spinPos->value();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -508,43 +538,41 @@ void Geometryval::slotGeometry()
     QRectF r = m_paramRect->rect().normalized();
 
     QDialog d(this);
-    m_view = new Ui::GeometryPosition_UI();
-    m_view->setupUi(&d);
+    m_view.setupUi(&d);
     d.setWindowTitle(i18n("Frame Geometry"));
-    m_view->value_x->setMaximum(10000);
-    m_view->value_x->setMinimum(-10000);
-    m_view->value_y->setMaximum(10000);
-    m_view->value_y->setMinimum(-10000);
-    m_view->value_width->setMaximum(500000);
-    m_view->value_width->setMinimum(1);
-    m_view->value_height->setMaximum(500000);
-    m_view->value_height->setMinimum(1);
+    m_view.value_x->setMaximum(10000);
+    m_view.value_x->setMinimum(-10000);
+    m_view.value_y->setMaximum(10000);
+    m_view.value_y->setMinimum(-10000);
+    m_view.value_width->setMaximum(500000);
+    m_view.value_width->setMinimum(1);
+    m_view.value_height->setMaximum(500000);
+    m_view.value_height->setMinimum(1);
 
-    m_view->value_x->setValue(m_paramRect->pos().x());
-    m_view->value_y->setValue(m_paramRect->pos().y());
-    m_view->value_width->setValue(r.width());
-    m_view->value_height->setValue(r.height());
-    connect(m_view->button_reset , SIGNAL(clicked()) , this , SLOT(slotResetPosition()));
+    m_view.value_x->setValue(m_paramRect->pos().x());
+    m_view.value_y->setValue(m_paramRect->pos().y());
+    m_view.value_width->setValue(r.width());
+    m_view.value_height->setValue(r.height());
+    connect(m_view.button_reset , SIGNAL(clicked()) , this , SLOT(slotResetPosition()));
 
     if (d.exec() == QDialog::Accepted) {
-        m_paramRect->setPos(m_view->value_x->value(), m_view->value_y->value());
-        m_paramRect->setRect(0, 0, m_view->value_width->value(), m_view->value_height->value());
+        m_paramRect->setPos(m_view.value_x->value(), m_view.value_y->value());
+        m_paramRect->setRect(0, 0, m_view.value_width->value(), m_view.value_height->value());
         slotUpdateTransitionProperties();
     }
-    delete m_view;
 }
 
 void Geometryval::slotResetPosition()
 {
-    m_view->value_x->setValue(0);
-    m_view->value_y->setValue(0);
+    m_view.value_x->setValue(0);
+    m_view.value_y->setValue(0);
 
     if (m_frameSize.isNull()) {
-        m_view->value_width->setValue(m_profile.width);
-        m_view->value_height->setValue(m_profile.height);
+        m_view.value_width->setValue(m_realWidth);
+        m_view.value_height->setValue(m_profile.height);
     } else {
-        m_view->value_width->setValue(m_frameSize.x());
-        m_view->value_height->setValue(m_frameSize.y());
+        m_view.value_width->setValue(m_frameSize.x());
+        m_view.value_height->setValue(m_frameSize.y());
     }
 }
 
@@ -552,3 +580,11 @@ void Geometryval::setFrameSize(QPoint p)
 {
     m_frameSize = p;
 }
+
+
+void Geometryval::slotKeyframeMoved(int pos)
+{
+    slotPositionChanged(pos);
+    slotUpdateTransitionProperties();
+}
+
