@@ -26,27 +26,28 @@
 #include "definitions.h"
 #include "ui_trackheader_ui.h"
 
-class HeaderTrack : public QWidget
+class HeaderTrack : public QWidget, public Ui::TrackHeader_UI
 {
     Q_OBJECT
 
 public:
     HeaderTrack(int index, TrackInfo info, int height, QWidget *parent = 0);
-    ~HeaderTrack();
+    //virtual ~HeaderTrack();
     void setLock(bool lock);
     void adjustSize(int height);
 
 private:
     int m_index;
     TRACKTYPE m_type;
-    Ui::TrackHeader_UI m_view;
 
 private slots:
     void switchAudio();
     void switchVideo();
     void slotDeleteTrack();
+    void deleteTrack();
     void slotAddTrack();
     void slotChangeTrack();
+    void slotRenameTrack();
     void switchLock(bool emitSignal = true);
 
 signals:
@@ -56,6 +57,7 @@ signals:
     void insertTrack(int);
     void deleteTrack(int);
     void changeTrack(int);
+    void renameTrack(int);
 };
 
 #endif
