@@ -75,6 +75,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
     m_configCapture.setupUi(p4);
     m_page4 = addPage(p4, i18n("Capture"), "media-record");
     m_configCapture.tabWidget->setCurrentIndex(KdenliveSettings::defaultcapture());
+#ifdef Q_WS_MAC
+    m_configCapture.tabWidget->setEnabled(false);
+    m_configCapture.kcfg_defaultcapture->setEnabled(false);
+    m_configCapture.label->setText(i18n("Capture is not yet available on OS X."));
+#endif
 
     QWidget *p5 = new QWidget;
     m_configShuttle.setupUi(p5);
@@ -207,12 +212,14 @@ void KdenliveSettingsDialog::initDevices()
 {
     // Fill audio drivers
     m_configSdl.kcfg_audio_driver->addItem(i18n("Automatic"), QString());
+#ifndef Q_WS_MAC
     m_configSdl.kcfg_audio_driver->addItem(i18n("OSS"), "dsp");
     m_configSdl.kcfg_audio_driver->addItem(i18n("ALSA"), "alsa");
     m_configSdl.kcfg_audio_driver->addItem(i18n("PulseAudio"), "pulse");
     m_configSdl.kcfg_audio_driver->addItem(i18n("OSS with DMA access"), "dma");
     m_configSdl.kcfg_audio_driver->addItem(i18n("Esound daemon"), "esd");
     m_configSdl.kcfg_audio_driver->addItem(i18n("ARTS daemon"), "artsc");
+#endif
 
     if (!KdenliveSettings::audiodrivername().isEmpty())
         for (int i = 1; i < m_configSdl.kcfg_audio_driver->count(); i++) {
@@ -224,6 +231,7 @@ void KdenliveSettingsDialog::initDevices()
 
     // Fill video drivers
     m_configSdl.kcfg_video_driver->addItem(i18n("Automatic"), QString());
+#ifndef Q_WS_MAC
     m_configSdl.kcfg_video_driver->addItem(i18n("XVideo"), "x11");
     m_configSdl.kcfg_video_driver->addItem(i18n("X11"), "x11_noaccel");
     m_configSdl.kcfg_video_driver->addItem(i18n("XFree86 DGA 2.0"), "dga");
@@ -233,6 +241,7 @@ void KdenliveSettingsDialog::initDevices()
     m_configSdl.kcfg_video_driver->addItem(i18n("SVGAlib"), "svgalib");
     m_configSdl.kcfg_video_driver->addItem(i18n("General graphics interface"), "ggi");
     m_configSdl.kcfg_video_driver->addItem(i18n("Ascii art library"), "aalib");
+#endif
 
     // Fill the list of audio playback devices
     m_configSdl.kcfg_audio_device->addItem(i18n("Default"), QString());
@@ -407,13 +416,25 @@ void KdenliveSettingsDialog::updateSettings()
     KdenliveSettings::setDefault_profile(m_defaultPath);
 
     bool resetProfile = false;
+    bool updateCapturePath = false;
 
     if (m_configEnv.capturefolderurl->url().path() != KdenliveSettings::capturefolder()) {
-        kDebug() << "/// CAPT FOLDER UPDATED";
         KdenliveSettings::setCapturefolder(m_configEnv.capturefolderurl->url().path());
-        emit updateCaptureFolder();
+        updateCapturePath = true;
     }
 
+    if (m_configCapture.kcfg_dvgrabfilename->text() != KdenliveSettings::dvgrabfilename()) {
+        KdenliveSettings::setDvgrabfilename(m_configCapture.kcfg_dvgrabfilename->text());
+        updateCapturePath = true;
+    }
+
+    if ((uint) m_configCapture.kcfg_firewireformat->currentIndex() != KdenliveSettings::firewireformat()) {
+        KdenliveSettings::setFirewireformat(m_configCapture.kcfg_firewireformat->currentIndex());
+        updateCapturePath = true;
+    }
+
+    if (updateCapturePath) emit updateCaptureFolder();
+
     QString value = m_configCapture.kcfg_rmd_alsa_device->itemData(m_configCapture.kcfg_rmd_alsa_device->currentIndex()).toString();
     if (value != KdenliveSettings::rmd_alsadevicename()) {
         KdenliveSettings::setRmd_alsadevicename(value);
