@@ -38,9 +38,10 @@
 #include <QToolBar>
 #include <QDesktopWidget>
 #include <QLabel>
+#include <QIntValidator>
 
 
-Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
+Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget *parent) :
         QWidget(parent),
         render(NULL),
         m_name(name),
@@ -51,7 +52,6 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
         m_isActive(false),
         m_scale(1),
         m_length(0),
-        m_position(-1),
         m_dragStarted(false)
 {
     m_ui.setupUi(this);
@@ -98,6 +98,13 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
         configButton->setMenu(m_configMenu);
         configButton->setPopupMode(QToolButton::QToolButton::InstantPopup);
         toolbar->addWidget(configButton);
+
+        if (name == "clip") {
+            m_markerMenu = new QMenu(i18n("Go to marker..."), this);
+            m_markerMenu->setEnabled(false);
+            m_configMenu->addMenu(m_markerMenu);
+            connect(m_markerMenu, SIGNAL(triggered(QAction *)), this, SLOT(slotGoToMarker(QAction *)));
+        }
         m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (100%)"), this, SLOT(slotSetSizeOneToOne()));
         m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (50%)"), this, SLOT(slotSetSizeOneToTwo()));
     }
@@ -107,7 +114,11 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
     toolbar->addWidget(spacer);
     m_timePos = new KRestrictedLine(this);
     m_timePos->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
-    m_timePos->setInputMask("99:99:99:99");
+    m_frametimecode = KdenliveSettings::frametimecode();
+    if (m_frametimecode) {
+        m_timePos->setInputMask(QString());
+        m_timePos->setValidator(new QIntValidator(this));
+    } else m_timePos->setInputMask("99:99:99:99");
     toolbar->addWidget(m_timePos);
 
     connect(m_timePos, SIGNAL(editingFinished()), this, SLOT(slotSeek()));
@@ -119,12 +130,25 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
 
     //m_ruler->setPixelPerMark(3);
 
+    if (profile.isEmpty()) profile = KdenliveSettings::current_profile();
+
     QVBoxLayout *rendererBox = new QVBoxLayout(m_ui.video_frame);
     rendererBox->setContentsMargins(0, 0, 0, 0);
+#ifdef Q_WS_MAC
+    m_glWidget = new VideoGLWidget(m_ui.video_frame);
+    rendererBox->addWidget(m_glWidget);
+    render = new Render(m_name, (int) m_ui.video_frame->winId(), -1, profile, this);
+    m_glWidget->setImageAspectRatio(render->dar());
+    m_glWidget->setBackgroundColor(KdenliveSettings::window_background());
+    m_glWidget->resize(m_ui.video_frame->size());
+    connect(render, SIGNAL(showImageSignal(QImage)), m_glWidget, SLOT(showImage(QImage)));
+    m_monitorRefresh = 0;
+#else
     m_monitorRefresh = new MonitorRefresh(m_ui.video_frame);
     rendererBox->addWidget(m_monitorRefresh);
-    render = new Render(m_name, (int) m_monitorRefresh->winId(), -1, this);
+    render = new Render(m_name, (int) m_monitorRefresh->winId(), -1, profile, this);
     m_monitorRefresh->setRenderer(render);
+#endif
 
     connect(m_ruler, SIGNAL(seekRenderer(int)), this, SLOT(slotSeek(int)));
     connect(render, SIGNAL(durationChanged(int)), this, SLOT(adjustRulerSize(int)));
@@ -141,7 +165,9 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
     } else {
         connect(m_ruler, SIGNAL(zoneChanged(QPoint)), this, SLOT(setClipZone(QPoint)));
     }
+#ifndef Q_WS_MAC
     m_monitorRefresh->show();
+#endif
     kDebug() << "/////// BUILDING MONITOR, ID: " << m_ui.video_frame->winId();
 }
 
@@ -151,6 +177,7 @@ Monitor::~Monitor()
     delete m_timePos;
     delete m_overlay;
     delete m_monitorRefresh;
+    delete render;
 }
 
 QString Monitor::name() const
@@ -169,15 +196,19 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
     m_playMenu->addAction(loopZone);
 
     //TODO: add save zone to timeline monitor when fixed
-    if (m_name == "clip") m_contextMenu->addAction(KIcon("document-save"), i18n("Save zone"), this, SLOT(slotSaveZone()));
-
+    if (m_name == "clip") {
+        m_contextMenu->addMenu(m_markerMenu);
+        m_contextMenu->addAction(KIcon("document-save"), i18n("Save zone"), this, SLOT(slotSaveZone()));
+    }
     QAction *extractFrame = m_configMenu->addAction(KIcon("document-new"), i18n("Extract frame"), this, SLOT(slotExtractCurrentFrame()));
     m_contextMenu->addAction(extractFrame);
 
     if (m_name != "clip") {
+#ifndef Q_WS_MAC
         QAction *splitView = m_contextMenu->addAction(KIcon("view-split-left-right"), i18n("Split view"), render, SLOT(slotSplitView(bool)));
         splitView->setCheckable(true);
         m_configMenu->addAction(splitView);
+#endif
     } else {
         QAction *setThumbFrame = m_contextMenu->addAction(KIcon("document-new"), i18n("Set current image as thumbnail"), this, SLOT(slotSetThumbFrame()));
         m_configMenu->addAction(setThumbFrame);
@@ -198,6 +229,12 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
 
 }
 
+void Monitor::slotGoToMarker(QAction *action)
+{
+    int pos = action->data().toInt();
+    slotSeek(pos);
+}
+
 void Monitor::slotSetSizeOneToOne()
 {
     QRect r = QApplication::desktop()->screenGeometry();
@@ -248,6 +285,26 @@ DocClipBase *Monitor::activeClip()
     return m_currentClip;
 }
 
+void Monitor::updateMarkers(DocClipBase *source)
+{
+    if (source == m_currentClip && source != NULL) {
+        m_markerMenu->clear();
+        QList <CommentedTime> markers = m_currentClip->commentedSnapMarkers();
+        if (!markers.isEmpty()) {
+            QList <int> marks;
+            for (int i = 0; i < markers.count(); i++) {
+                int pos = (int) markers.at(i).time().frames(m_monitorManager->timecode().fps());
+                marks.append(pos);
+                QString position = m_monitorManager->timecode().getTimecode(markers.at(i).time()) + ' ' + markers.at(i).comment();
+                QAction *go = m_markerMenu->addAction(position);
+                go->setData(pos);
+            }
+            m_ruler->setMarkers(marks);
+        } else m_ruler->setMarkers(QList <int>());
+        m_markerMenu->setEnabled(!m_markerMenu->isEmpty());
+    }
+}
+
 void Monitor::slotSeekToPreviousSnap()
 {
     if (m_currentClip) slotSeek(getSnapForPos(true).frames(m_monitorManager->timecode().fps()));
@@ -260,7 +317,7 @@ void Monitor::slotSeekToNextSnap()
 
 GenTime Monitor::position()
 {
-    return GenTime(m_position, m_monitorManager->timecode().fps());
+    return render->seekPosition();
 }
 
 GenTime Monitor::getSnapForPos(bool previous)
@@ -278,7 +335,7 @@ GenTime Monitor::getSnapForPos(bool previous)
     snaps.append(m_currentClip->duration());
     qSort(snaps);
 
-    const GenTime pos(m_position, m_monitorManager->timecode().fps());
+    const GenTime pos = render->seekPosition();
     for (int i = 0; i < snaps.size(); ++i) {
         if (previous && snaps.at(i) >= pos) {
             if (i == 0) i = 1;
@@ -301,7 +358,7 @@ void Monitor::slotZoneMoved(int start, int end)
 
 void Monitor::slotSetZoneStart()
 {
-    m_ruler->setZone(m_position, -1);
+    m_ruler->setZone(render->seekFramePosition(), -1);
     emit zoneUpdated(m_ruler->zone());
     checkOverlay();
     setClipZone(m_ruler->zone());
@@ -309,7 +366,7 @@ void Monitor::slotSetZoneStart()
 
 void Monitor::slotSetZoneEnd()
 {
-    m_ruler->setZone(-1, m_position);
+    m_ruler->setZone(-1, render->seekFramePosition());
     emit zoneUpdated(m_ruler->zone());
     checkOverlay();
     setClipZone(m_ruler->zone());
@@ -331,7 +388,8 @@ void Monitor::mouseReleaseEvent(QMouseEvent * event)
 {
     if (m_dragStarted) {
         if (m_ui.video_frame->underMouse()) {
-            slotPlay();
+            if (isActive()) slotPlay();
+            else activateMonitor();
         } else QWidget::mouseReleaseEvent(event);
         m_dragStarted = false;
     }
@@ -411,10 +469,10 @@ void Monitor::wheelEvent(QWheelEvent * event)
 {
     if (event->modifiers() == Qt::ControlModifier) {
         int delta = m_monitorManager->timecode().fps();
-        if (event->delta() < 0) delta = 0 - delta;
-        slotSeek(m_position - delta);
+        if (event->delta() > 0) delta = 0 - delta;
+        slotSeek(render->seekFramePosition() - delta);
     } else {
-        if (event->delta() <= 0) slotForwardOneFrame();
+        if (event->delta() >= 0) slotForwardOneFrame();
         else slotRewindOneFrame();
     }
 }
@@ -424,17 +482,25 @@ void Monitor::slotSetThumbFrame()
     if (m_currentClip == NULL) {
         return;
     }
-    m_currentClip->setClipThumbFrame((uint) m_position);
+    m_currentClip->setClipThumbFrame((uint) render->seekFramePosition());
     emit refreshClipThumbnail(m_currentClip->getId());
 }
 
 void Monitor::slotExtractCurrentFrame()
 {
-    QPixmap frame = render->extractFrame(m_position);
-    QString outputFile = KFileDialog::getSaveFileName(KUrl(), "image/png");
-    if (!outputFile.isEmpty()) {
-        if (QFile::exists(outputFile) && KMessageBox::questionYesNo(this, i18n("File already exists.\nDo you want to overwrite it?")) == KMessageBox::No) return;
-        frame.save(outputFile);
+    QImage frame = render->extractFrame(render->seekFramePosition());
+    KFileDialog *fs = new KFileDialog(KUrl(), "image/png", this);
+    fs->setOperationMode(KFileDialog::Saving);
+    fs->setMode(KFile::File);
+#if KDE_IS_VERSION(4,2,0)
+    fs->setConfirmOverwrite(true);
+#endif
+    fs->setKeepLocation(true);
+    fs->exec();
+    QString path = fs->selectedFile();
+    delete fs;
+    if (!path.isEmpty()) {
+        frame.save(path);
     }
 }
 
@@ -450,13 +516,19 @@ void Monitor::activateMonitor()
 
 void Monitor::setTimePos(const QString &pos)
 {
-    m_timePos->setText(pos);
+    if (m_frametimecode) {
+        int frames = m_monitorManager->timecode().getFrameCount(pos);
+        m_timePos->setText(QString::number(frames));
+    } else m_timePos->setText(pos);
     slotSeek();
 }
 
 void Monitor::slotSeek()
 {
-    const int frames = m_monitorManager->timecode().getFrameCount(m_timePos->text(), m_monitorManager->timecode().fps());
+    int frames;
+    if (m_frametimecode) frames = m_timePos->text().toInt();
+    else frames = m_monitorManager->timecode().getFrameCount(m_timePos->text());
+    //kDebug() << "// / / SEEK TO: " << frames;
     slotSeek(frames);
 }
 
@@ -464,20 +536,20 @@ void Monitor::slotSeek(int pos)
 {
     activateMonitor();
     if (render == NULL) return;
-    m_position = pos;
     render->seekToFrame(pos);
-    emit renderPosition(m_position);
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::checkOverlay()
 {
     if (m_overlay == NULL) return;
+    int pos = render->seekFramePosition();
     QPoint zone = m_ruler->zone();
-    if (m_position == zone.x()) m_overlay->setOverlayText(i18n("In Point"));
-    else if (m_position == zone.y()) m_overlay->setOverlayText(i18n("Out Point"));
+    if (pos == zone.x()) m_overlay->setOverlayText(i18n("In Point"));
+    else if (pos == zone.y()) m_overlay->setOverlayText(i18n("Out Point"));
     else {
         if (m_currentClip) {
-            QString markerComment = m_currentClip->markerComment(GenTime(m_position, m_monitorManager->timecode().fps()));
+            QString markerComment = m_currentClip->markerComment(GenTime(pos, m_monitorManager->timecode().fps()));
             if (markerComment.isEmpty()) m_overlay->setHidden(true);
             else m_overlay->setOverlayText(markerComment, false);
         } else m_overlay->setHidden(true);
@@ -488,36 +560,32 @@ void Monitor::slotStart()
 {
     activateMonitor();
     render->play(0);
-    m_position = 0;
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrame(0);
+    emit renderPosition(0);
 }
 
 void Monitor::slotEnd()
 {
     activateMonitor();
     render->play(0);
-    m_position = render->getLength();
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrame(render->getLength());
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotZoneStart()
 {
     activateMonitor();
     render->play(0);
-    m_position = m_ruler->zone().x();
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrame(m_ruler->zone().x());
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotZoneEnd()
 {
     activateMonitor();
     render->play(0);
-    m_position = m_ruler->zone().y();
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrame(m_ruler->zone().y());
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotRewind(double speed)
@@ -548,34 +616,24 @@ void Monitor::slotRewindOneFrame(int diff)
 {
     activateMonitor();
     render->play(0);
-    if (m_position < 1) return;
-    /*
-     * freebsd needs this hack to upgrade m_position value:
-     * http://www.kdenlive.org/mantis/view.php?id=491
-     */
-    int position = m_position - diff;
-    m_position = qMax(position, 0);
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrameDiff(-diff);
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotForwardOneFrame(int diff)
 {
     activateMonitor();
     render->play(0);
-    if (m_position >= m_length) return;
-    m_position += diff;
-    m_position = qMin(m_position, m_length);
-    render->seekToFrame(m_position);
-    emit renderPosition(m_position);
+    render->seekToFrameDiff(diff);
+    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::seekCursor(int pos)
 {
     activateMonitor();
     checkOverlay();
-    m_position = pos;
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+    if (m_frametimecode) m_timePos->setText(QString::number(pos));
+    else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     m_ruler->slotNewValue(pos);
 }
 
@@ -589,9 +647,9 @@ void Monitor::rendererStopped(int pos)
         }
     }
     m_ruler->slotNewValue(pos);
-    m_position = pos;
     checkOverlay();
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+    if (m_frametimecode) m_timePos->setText(QString::number(pos));
+    else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     m_playAction->setChecked(false);
     m_playAction->setIcon(m_playIcon);
 }
@@ -669,7 +727,7 @@ void Monitor::slotPlayZone()
     if (render == NULL) return;
     activateMonitor();
     QPoint p = m_ruler->zone();
-    render->playZone(GenTime(p.x(), render->fps()), GenTime(p.y(), render->fps()));
+    render->playZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
     m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
@@ -679,7 +737,7 @@ void Monitor::slotLoopZone()
     if (render == NULL) return;
     activateMonitor();
     QPoint p = m_ruler->zone();
-    render->loopZone(GenTime(p.x(), render->fps()), GenTime(p.y(), render->fps()));
+    render->loopZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
     m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
@@ -695,12 +753,12 @@ void Monitor::slotSetXml(DocClipBase *clip, const int position)
     }
     if (clip != m_currentClip) {
         m_currentClip = clip;
+        updateMarkers(clip);
         if (render->setProducer(clip->producer(), position) == -1) {
             // MLT CONSUMER is broken
             emit blockMonitors();
         }
-        m_position = position;
-    } else if (position != -1) render->seek(GenTime(position, render->fps()));
+    } else if (position != -1) render->seek(GenTime(position, m_monitorManager->timecode().fps()));
 }
 
 void Monitor::slotOpenFile(const QString &file)
@@ -726,10 +784,10 @@ void Monitor::slotSaveZone()
 }
 
 
-void Monitor::resetProfile()
+void Monitor::resetProfile(const QString profile)
 {
     if (render == NULL) return;
-    render->resetProfile();
+    render->resetProfile(profile);
 }
 
 void Monitor::saveSceneList(QString path, QDomElement info)
@@ -761,15 +819,35 @@ void Monitor::slotSwitchMonitorInfo(bool show)
     KdenliveSettings::setDisplayMonitorInfo(show);
     if (show) {
         if (m_overlay) return;
+#ifndef Q_WS_MAC
         m_overlay = new Overlay(m_monitorRefresh);
         m_overlay->raise();
         m_overlay->setHidden(true);
+#else
+        m_overlay = new Overlay(m_glWidget);
+#endif
     } else {
         delete m_overlay;
         m_overlay = NULL;
     }
 }
 
+void Monitor::updateTimecodeFormat()
+{
+    m_frametimecode = KdenliveSettings::frametimecode();
+    if (m_frametimecode) {
+        int frames = m_monitorManager->timecode().getFrameCount(m_timePos->text());
+        m_timePos->setValidator(new QIntValidator(this));
+        m_timePos->setInputMask(QString());
+        m_timePos->setText(QString::number(frames));
+    } else {
+        int pos = m_timePos->text().toInt();
+        m_timePos->setValidator(0);
+        m_timePos->setInputMask("99:99:99:99");
+        m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+    }
+}
+
 
 MonitorRefresh::MonitorRefresh(QWidget* parent) : \
         QWidget(parent),
