@@ -71,6 +71,9 @@ public:
       extendItem(w,
     }
     */
+    void drawFocus(QPainter *, const QStyleOptionViewItem &, const QRect &) const {
+    }
+
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const {
         if (index.column() == 1) {
             QRect r1 = option.rect;
@@ -83,9 +86,9 @@ public:
             font.setBold(true);
             painter->setFont(font);
             int mid = (int)((r1.height() / 2));
-            r1.setBottom(r1.y() + mid);
+            r1.adjust(2, 0, 0, -mid);
             QRect r2 = option.rect;
-            r2.setTop(r2.y() + mid);
+            r2.adjust(2, mid, 0, 0);
             painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data().toString());
             //painter->setPen(Qt::green);
             font.setBold(false);
@@ -123,7 +126,6 @@ public:
     QDomElement producersList();
     void setRenderer(Render *projectRender);
     void slotUpdateClipProperties(const QString &id, QMap <QString, QString> properties);
-    void updateAllClips();
     QByteArray headerInfo() const;
     void setHeaderInfo(const QByteArray &state);
     void setupMenu(QMenu *addMenu, QAction *defaultAction);
@@ -131,9 +133,12 @@ public:
     QString currentClipUrl() const;
     void reloadClipThumbnails();
     QDomDocument generateTemplateXml(QString data, const QString &replaceString);
+    void cleanup();
+    void trashUnusedClips();
 
 public slots:
     void setDocument(KdenliveDoc *doc);
+    void updateAllClips();
     void slotReplyGetImage(const QString &clipId, const QPixmap &pix);
     void slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata, bool replace);
     void slotAddClip(DocClipBase *clip, bool getProperties);
@@ -149,7 +154,7 @@ public slots:
     void slotResetProjectList();
     void slotOpenClip();
     void slotEditClip();
-    void slotReloadClip();
+    void slotReloadClip(const QString &id = QString());
     void slotAddColorClip();
     void regenerateTemplate(const QString &id);
 
@@ -169,8 +174,10 @@ private:
     QAction *m_deleteAction;
     QAction *m_openAction;
     QAction *m_reloadAction;
+    QMenu *m_transcodeAction;
     KdenliveDoc *m_doc;
     ProjectItem *m_selectedItem;
+    ItemDelegate *m_listViewDelegate;
     bool m_refreshed;
     QToolButton *m_addButton;
     QMap <QString, QDomElement> m_infoQueue;
@@ -182,7 +189,6 @@ private:
     void editFolder(const QString folderName, const QString oldfolderName, const QString &clipId);
     QStringList getGroup() const;
     void regenerateTemplate(ProjectItem *clip);
-    void regenerateTemplateImage(ProjectItem *clip);
 
 private slots:
     void slotClipSelected();
@@ -202,11 +208,12 @@ private slots:
 
 signals:
     void clipSelected(DocClipBase *);
-    void getFileProperties(const QDomElement&, const QString &, bool);
+    void getFileProperties(const QDomElement, const QString &, bool);
     void receivedClipDuration(const QString &);
     void showClipProperties(DocClipBase *);
     void projectModified();
     void loadingIsOver();
+    void displayMessage(const QString, int progress);
     void clipNameChanged(const QString, const QString);
     void refreshClip();
 };
