@@ -30,6 +30,11 @@
 #include <KComboBox>
 #include <KIO/NetAccess>
 #include <KFileItem>
+#include <KMessageBox>
+
+#if KDE_IS_VERSION(4,2,0)
+#include <KDiskFreeSpaceInfo>
+#endif
 
 #include <QMouseEvent>
 #include <QMenu>
@@ -46,11 +51,11 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
         m_didCapture(false),
         m_isPlaying(false)
 {
-    m_ui.setupUi(this);
+    setupUi(this);
 
-    m_ui.video_frame->setAttribute(Qt::WA_PaintOnScreen);
-    m_ui.device_selector->setCurrentIndex(KdenliveSettings::defaultcapture());
-    connect(m_ui.device_selector, SIGNAL(currentIndexChanged(int)), this, SLOT(slotVideoDeviceChanged(int)));
+    video_frame->setAttribute(Qt::WA_PaintOnScreen);
+    device_selector->setCurrentIndex(KdenliveSettings::defaultcapture());
+    connect(device_selector, SIGNAL(currentIndexChanged(int)), this, SLOT(slotVideoDeviceChanged(int)));
 
 
 
@@ -86,16 +91,32 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
     configAction->setCheckable(false);
 
     layout->addWidget(toolbar);
-    m_ui.control_frame_firewire->setLayout(layout);
 
-    slotVideoDeviceChanged(m_ui.device_selector->currentIndex());
+    layout->addWidget(&m_dvinfo);
+
+#if KDE_IS_VERSION(4,2,0)
+    m_freeSpace = new KCapacityBar(KCapacityBar::DrawTextInline, this);
+    m_freeSpace->setMaximumWidth(150);
+    QFontMetricsF fontMetrics(font());
+    m_freeSpace->setMaximumHeight(fontMetrics.height() * 1.2);
+    slotUpdateFreeSpace();
+    layout->addWidget(m_freeSpace);
+    connect(&m_spaceTimer, SIGNAL(timeout()), this, SLOT(slotUpdateFreeSpace()));
+    m_spaceTimer.setInterval(30000);
+    m_spaceTimer.setSingleShot(false);
+#endif
+
+    control_frame_firewire->setLayout(layout);
+
+    slotVideoDeviceChanged(device_selector->currentIndex());
     m_displayProcess = new QProcess;
     m_captureProcess = new QProcess;
 
     connect(m_captureProcess, SIGNAL(stateChanged(QProcess::ProcessState)), this, SLOT(slotProcessStatus(QProcess::ProcessState)));
+    connect(m_captureProcess, SIGNAL(readyReadStandardError()), this, SLOT(slotReadDvgrabInfo()));
 
     QStringList env = QProcess::systemEnvironment();
-    env << "SDL_WINDOWID=" + QString::number(m_ui.video_frame->winId());
+    env << "SDL_WINDOWID=" + QString::number(video_frame->winId());
 
     QString videoDriver = KdenliveSettings::videodrivername();
     if (!videoDriver.isEmpty()) {
@@ -116,11 +137,14 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
         KdenliveSettings::setVideo4capture(captureCommand);
     }
 
-    kDebug() << "/////// BUILDING MONITOR, ID: " << m_ui.video_frame->winId();
+    kDebug() << "/////// BUILDING MONITOR, ID: " << video_frame->winId();
 }
 
 RecMonitor::~RecMonitor()
 {
+#if KDE_IS_VERSION(4,2,0)
+    m_spaceTimer.stop();
+#endif
     delete m_captureProcess;
     delete m_displayProcess;
 }
@@ -132,13 +156,23 @@ QString RecMonitor::name() const
 
 void RecMonitor::slotConfigure()
 {
-    emit showConfigDialog(4, m_ui.device_selector->currentIndex());
+    emit showConfigDialog(4, device_selector->currentIndex());
 }
 
 void RecMonitor::slotUpdateCaptureFolder()
 {
     if (m_captureProcess) m_captureProcess->setWorkingDirectory(KdenliveSettings::capturefolder());
-    slotVideoDeviceChanged(m_ui.device_selector->currentIndex());
+    if (m_captureProcess->state() != QProcess::NotRunning) {
+        if (device_selector->currentIndex() == FIREWIRE)
+            KMessageBox::information(this, i18n("You need to disconnect and reconnect in the capture monitor to apply your changes"), i18n("Capturing"));
+        else KMessageBox::information(this, i18n("You need to stop capture before your changes can be applied"), i18n("Capturing"));
+    } else slotVideoDeviceChanged(device_selector->currentIndex());
+    kDebug() << "// UPDATE CAPT FOLD: " << KdenliveSettings::capturefolder();
+
+#if KDE_IS_VERSION(4,2,0)
+    // update free space info
+    slotUpdateFreeSpace();
+#endif
 }
 
 void RecMonitor::slotVideoDeviceChanged(int ix)
@@ -153,11 +187,11 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         m_playAction->setEnabled(false);
         if (KdenliveSettings::rmd_path().isEmpty()) {
             QString rmdpath = KStandardDirs::findExe("recordmydesktop");
-            if (rmdpath.isEmpty()) m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("Recordmydesktop utility not found,\n please install it for screen grabs")));
+            if (rmdpath.isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("Recordmydesktop utility not found,\n please install it for screen grabs")));
             else KdenliveSettings::setRmd_path(rmdpath);
         }
-        if (!KdenliveSettings::rmd_path().isEmpty()) m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
-        //m_ui.video_frame->setText(i18n("Press record button\nto start screen capture"));
+        if (!KdenliveSettings::rmd_path().isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
+        //video_frame->setText(i18n("Press record button\nto start screen capture"));
         break;
     case VIDEO4LINUX:
         m_discAction->setEnabled(false);
@@ -175,14 +209,35 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         m_playAction->setEnabled(false);
         m_rewAction->setEnabled(false);
         m_fwdAction->setEnabled(false);
-        //m_ui.video_frame->setText(i18n("Plug your camcorder and\npress connect button\nto initialize connection"));
+
+        // Check that dvgab is available
         if (KdenliveSettings::dvgrab_path().isEmpty()) {
             QString dvgrabpath = KStandardDirs::findExe("dvgrab");
-            if (dvgrabpath.isEmpty()) m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("dvgrab utility not found,\n please install it for firewire capture")));
+            if (dvgrabpath.isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("dvgrab utility not found,\n please install it for firewire capture")));
             else KdenliveSettings::setDvgrab_path(dvgrabpath);
+        } else {
+            // Show capture info
+            QString capturefile = KdenliveSettings::capturefolder();
+            if (!capturefile.endsWith("/")) capturefile.append("/");
+            QString capturename = KdenliveSettings::dvgrabfilename();
+            if (capturename.isEmpty()) capturename = "capture";
+            QString extension;
+            switch (KdenliveSettings::firewireformat()) {
+            case 0:
+                extension = ".dv";
+                break;
+            case 1:
+            case 2:
+                extension = ".avi";
+                break;
+            case 3:
+                extension = ".m2t";
+                break;
+            }
+            capturename.append("xxx" + extension);
+            capturefile.append(capturename);
+            video_frame->setPixmap(mergeSideBySide(KIcon("network-connect").pixmap(QSize(50, 50)), i18n("Plug your camcorder and\npress connect button\nto initialize connection\nFiles will be saved in:\n%1", capturefile)));
         }
-
-        if (!KdenliveSettings::dvgrab_path().isEmpty()) m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("network-connect").pixmap(QSize(50, 50)), i18n("Plug your camcorder and\npress connect button\nto initialize connection\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
         break;
     }
 }
@@ -190,7 +245,7 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
 QPixmap RecMonitor::mergeSideBySide(const QPixmap& pix, const QString txt)
 {
     QPainter p;
-    QRect r = QApplication::fontMetrics().boundingRect(QRect(0, 0, m_ui.video_frame->width(), m_ui.video_frame->height()), Qt::AlignLeft, txt);
+    QRect r = QApplication::fontMetrics().boundingRect(QRect(0, 0, video_frame->width(), video_frame->height()), Qt::AlignLeft, txt);
     int strWidth = r.width();
     int strHeight = r.height();
     int pixWidth = pix.width();
@@ -210,10 +265,10 @@ void RecMonitor::checkDeviceAvailability()
     if (!KIO::NetAccess::exists(KUrl(KdenliveSettings::video4vdevice()), KIO::NetAccess::SourceSide , this)) {
         m_playAction->setEnabled(false);
         m_recAction->setEnabled(false);
-        m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice())));
-        //m_ui.video_frame->setText(i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice()));
-    } else //m_ui.video_frame->setText(i18n("Press play or record button\nto start video capture"));
-        m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Press play or record button\nto start video capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
+        video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice())));
+        //video_frame->setText(i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice()));
+    } else //video_frame->setText(i18n("Press play or record button\nto start video capture"));
+        video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Press play or record button\nto start video capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
 }
 
 void RecMonitor::slotDisconnect()
@@ -251,7 +306,7 @@ void RecMonitor::slotForward()
 void RecMonitor::slotStopCapture()
 {
     // stop capture
-    switch (m_ui.device_selector->currentIndex()) {
+    switch (device_selector->currentIndex()) {
     case FIREWIRE:
         m_captureProcess->write("\e", 2);
         m_playAction->setIcon(m_playIcon);
@@ -273,47 +328,8 @@ void RecMonitor::slotStopCapture()
 
 void RecMonitor::slotStartCapture(bool play)
 {
-
-    /*
-    *captureProcess<<"dvgrab";
-
-    bool isHdv = false;
-
-    switch (m_recPanel->capture_format->currentItem()){
-        case 0:
-      *captureProcess<<"--format"<<"dv1";
-     break;
-        case 1:
-      *captureProcess<<"--format"<<"dv2";
-     break;
-        case 3:
-      *captureProcess<<"--format"<<"hdv";
-     isHdv = true;
-     break;
-        default:
-            *captureProcess<<"--format"<<"raw";
-     break;
-    }
-
-    if (KdenliveSettings::autosplit()) *captureProcess<<"--autosplit";
-    if (KdenliveSettings::timestamp()) *captureProcess<<"--timestamp";
-    *captureProcess<<"-i"<<"capture"<<"-";*/
-
-    /*
-        QStringList captureArgs;
-        captureArgs<<"--format"<<"hdv"<<"-i"<<"capture"<<"-";
-        QStringList displayArgs;
-
-        displayArgs<<"-f"<<"mpegts"<<"-x"<<QString::number(m_ui.video_frame->width())<<"-y"<<QString::number(m_ui.video_frame->height())<<"-";
-
-        captureProcess->setStandardOutputProcess(displayProcess);
-        m_ui.video_frame->setScaledContents(false);
-        captureProcess->start("dvgrab",captureArgs);
-        displayProcess->start("ffplay",  displayArgs);*/
-
-
     if (m_captureProcess->state() != QProcess::NotRunning) {
-        if (m_ui.device_selector->currentIndex() == FIREWIRE) {
+        if (device_selector->currentIndex() == FIREWIRE) {
             if (m_isPlaying) {
                 m_captureProcess->write("k", 1);
                 //captureProcess->write("\e", 2);
@@ -330,8 +346,10 @@ void RecMonitor::slotStartCapture(bool play)
     m_captureArgs.clear();
     m_displayArgs.clear();
     m_isPlaying = false;
+    QString capturename = KdenliveSettings::dvgrabfilename();
+    QStringList dvargs = KdenliveSettings::dvgrabextra().simplified().split(" ", QString::SkipEmptyParts);
 
-    switch (m_ui.device_selector->currentIndex()) {
+    switch (device_selector->currentIndex()) {
     case FIREWIRE:
         switch (KdenliveSettings::firewireformat()) {
         case 0:
@@ -357,19 +375,26 @@ void RecMonitor::slotStartCapture(bool play)
         }
         if (KdenliveSettings::firewireautosplit()) m_captureArgs << "--autosplit";
         if (KdenliveSettings::firewiretimestamp()) m_captureArgs << "--timestamp";
-        m_captureArgs << "-i" << "capture" << "-";
-        m_displayArgs << "-x" << QString::number(m_ui.video_frame->width()) << "-y" << QString::number(m_ui.video_frame->height()) << "-";
+        if (!dvargs.isEmpty()) {
+            m_captureArgs << dvargs;
+        }
+        m_captureArgs << "-i";
+        if (capturename.isEmpty()) capturename = "capture";
+        m_captureArgs << capturename << "-";
+
+        m_displayArgs << "-x" << QString::number(video_frame->width()) << "-y" << QString::number(video_frame->height()) << "-";
 
         m_captureProcess->setStandardOutputProcess(m_displayProcess);
         m_captureProcess->setWorkingDirectory(KdenliveSettings::capturefolder());
         kDebug() << "Capture: Running dvgrab " << m_captureArgs.join(" ");
+
         m_captureProcess->start(KdenliveSettings::dvgrab_path(), m_captureArgs);
         if (play) m_captureProcess->write(" ", 1);
         m_discAction->setEnabled(true);
         break;
     case VIDEO4LINUX:
         m_captureArgs << KdenliveSettings::video4capture().simplified().split(' ') << KdenliveSettings::video4encoding().simplified().split(' ') << "-f" << "mpegts" << "-vcodec" << "mpeg4" << "-acodec" << "mp2" << "-";
-        m_displayArgs << "-f" << "mpegts" << "-x" << QString::number(m_ui.video_frame->width()) << "-y" << QString::number(m_ui.video_frame->height()) << "-";
+        m_displayArgs << "-f" << "mpegts" << "-x" << QString::number(video_frame->width()) << "-y" << QString::number(video_frame->height()) << "-";
         m_captureProcess->setStandardOutputProcess(m_displayProcess);
         kDebug() << "Capture: Running ffmpeg " << m_captureArgs.join(" ");
         m_captureProcess->start("ffmpeg", m_captureArgs);
@@ -378,10 +403,10 @@ void RecMonitor::slotStartCapture(bool play)
         break;
     }
 
-    if (m_ui.device_selector->currentIndex() != SCREENGRAB) {
+    if (device_selector->currentIndex() != SCREENGRAB) {
         kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
         m_displayProcess->start("ffplay", m_displayArgs);
-        m_ui.video_frame->setText(i18n("Initialising..."));
+        video_frame->setText(i18n("Initialising..."));
     } else {
         // do something when starting screen grab
     }
@@ -389,11 +414,11 @@ void RecMonitor::slotStartCapture(bool play)
 
 void RecMonitor::slotRecord()
 {
-    if (m_captureProcess->state() == QProcess::NotRunning && m_ui.device_selector->currentIndex() == FIREWIRE) {
+    if (m_captureProcess->state() == QProcess::NotRunning && device_selector->currentIndex() == FIREWIRE) {
         slotStartCapture();
     }
     if (m_isCapturing) {
-        switch (m_ui.device_selector->currentIndex()) {
+        switch (device_selector->currentIndex()) {
         case FIREWIRE:
             m_captureProcess->write("\e", 2);
             m_playAction->setIcon(m_playIcon);
@@ -410,22 +435,25 @@ void RecMonitor::slotRecord()
         case SCREENGRAB:
             //captureProcess->write("q\n", 3);
             m_captureProcess->terminate();
-            m_ui.video_frame->setText(i18n("Encoding captured video..."));
+            video_frame->setText(i18n("Encoding captured video..."));
             // in case ffmpeg doesn't exit with the 'q' command, kill it one second later
             //QTimer::singleShot(1000, captureProcess, SLOT(kill()));
             break;
         }
         return;
-    } else if (m_ui.device_selector->currentIndex() == FIREWIRE) {
+    } else if (device_selector->currentIndex() == FIREWIRE) {
         m_isCapturing = true;
         m_didCapture = true;
         m_captureProcess->write("c\n", 3);
+#if KDE_IS_VERSION(4,2,0)
+        m_spaceTimer.start();
+#endif
         return;
     }
     if (m_captureProcess->state() == QProcess::NotRunning) {
         m_recAction->setChecked(true);
         QString extension = "mp4";
-        if (m_ui.device_selector->currentIndex() == SCREENGRAB) extension = "ogv"; //KdenliveSettings::screengrabextension();
+        if (device_selector->currentIndex() == SCREENGRAB) extension = "ogv"; //KdenliveSettings::screengrabextension();
         QString path = KdenliveSettings::capturefolder() + "/capture0000." + extension;
         int i = 1;
         while (QFile::exists(path)) {
@@ -433,24 +461,18 @@ void RecMonitor::slotRecord()
             path = KdenliveSettings::capturefolder() + "/capture" + num + '.' + extension;
             i++;
         }
-
         m_captureFile = KUrl(path);
 
         m_captureArgs.clear();
         m_displayArgs.clear();
         QString args;
+        QString capturename = KdenliveSettings::dvgrabfilename();
+        if (capturename.isEmpty()) capturename = "capture";
 
-        switch (m_ui.device_selector->currentIndex()) {
-        case FIREWIRE:
-            m_captureArgs << "--format" << "hdv" << "-i" << "capture" << "-";
-            m_displayArgs << "-f" << "mpegts" << "-x" << QString::number(m_ui.video_frame->width()) << "-y" << QString::number(m_ui.video_frame->height()) << "-";
-            m_captureProcess->setStandardOutputProcess(m_displayProcess);
-            kDebug() << "Capture: Running dvgrab " << m_captureArgs.join(" ");
-            m_captureProcess->start(KdenliveSettings::dvgrab_path(), m_captureArgs);
-            break;
+        switch (device_selector->currentIndex()) {
         case VIDEO4LINUX:
             m_captureArgs << KdenliveSettings::video4capture().simplified().split(' ') << KdenliveSettings::video4encoding().simplified().split(' ') << "-vcodec" << "mpeg4" << "-acodec" << "mp2" << "-y" << m_captureFile.path() << "-f" << "mpegts" << "-vcodec" << "mpeg4" << "-acodec" << "mp2" << "-";
-            m_displayArgs << "-f" << "mpegts" << "-x" << QString::number(m_ui.video_frame->width()) << "-y" << QString::number(m_ui.video_frame->height()) << "-";
+            m_displayArgs << "-f" << "mpegts" << "-x" << QString::number(video_frame->width()) << "-y" << QString::number(video_frame->height()) << "-";
             m_captureProcess->setStandardOutputProcess(m_displayProcess);
             kDebug() << "Capture: Running ffmpeg " << m_captureArgs.join(" ");
             m_captureProcess->start("ffmpeg", m_captureArgs);
@@ -498,11 +520,11 @@ void RecMonitor::slotRecord()
         }
 
 
-        if (m_ui.device_selector->currentIndex() != SCREENGRAB) {
+        if (device_selector->currentIndex() != SCREENGRAB) {
             m_isCapturing = true;
             kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
             m_displayProcess->start("ffplay", m_displayArgs);
-            m_ui.video_frame->setText(i18n("Initialising..."));
+            video_frame->setText(i18n("Initialising..."));
         }
     } else {
         // stop capture
@@ -530,7 +552,7 @@ void RecMonitor::slotStartGrab(const QRect &rect) {
     }
     m_captureArgs << args.simplified().split(' ') << KdenliveSettings::screengrabencoding().simplified().split(' ') << m_captureFile.path();
     m_isCapturing = true;
-    m_ui.video_frame->setText(i18n("Capturing..."));
+    video_frame->setText(i18n("Capturing..."));
     if (KdenliveSettings::screengrabenableaudio() && !KdenliveSettings::useosscapture()) {
         QStringList alsaArgs = KdenliveSettings::screengrabalsacapture().simplified().split(' ');
         alsaProcess->setStandardOutputProcess(captureProcess);
@@ -545,9 +567,9 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
 {
     if (status == QProcess::NotRunning) {
         m_displayProcess->kill();
-        if (m_isCapturing && m_ui.device_selector->currentIndex() != FIREWIRE)
-            if (m_ui.autoaddbox->isChecked() && QFile::exists(m_captureFile.path())) emit addProjectClip(m_captureFile);
-        if (m_ui.device_selector->currentIndex() == FIREWIRE) {
+        if (m_isCapturing && device_selector->currentIndex() != FIREWIRE)
+            if (autoaddbox->isChecked() && QFile::exists(m_captureFile.path())) emit addProjectClip(m_captureFile);
+        if (device_selector->currentIndex() == FIREWIRE) {
             m_discAction->setIcon(KIcon("network-connect"));
             m_discAction->setText(i18n("Connect"));
             m_playAction->setEnabled(false);
@@ -559,17 +581,24 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
         m_playAction->setIcon(m_playIcon);
         m_recAction->setChecked(false);
         m_stopAction->setEnabled(false);
-        m_ui.device_selector->setEnabled(true);
+        device_selector->setEnabled(true);
         if (m_captureProcess && m_captureProcess->exitStatus() == QProcess::CrashExit) {
-            m_ui.video_frame->setText(i18n("Capture crashed, please check your parameters"));
+            video_frame->setText(i18n("Capture crashed, please check your parameters"));
         } else {
-            if (m_ui.device_selector->currentIndex() != SCREENGRAB) m_ui.video_frame->setText(i18n("Not connected"));
-            else m_ui.video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
+            if (device_selector->currentIndex() != SCREENGRAB) video_frame->setText(i18n("Not connected"));
+            else video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", KdenliveSettings::capturefolder())));
         }
         m_isCapturing = false;
+
+#if KDE_IS_VERSION(4,2,0)
+        m_spaceTimer.stop();
+        // update free space info
+        slotUpdateFreeSpace();
+#endif
+
     } else {
-        if (m_ui.device_selector->currentIndex() != SCREENGRAB) m_stopAction->setEnabled(true);
-        m_ui.device_selector->setEnabled(false);
+        if (device_selector->currentIndex() != SCREENGRAB) m_stopAction->setEnabled(true);
+        device_selector->setEnabled(false);
     }
 }
 
@@ -590,7 +619,9 @@ void RecMonitor::manageCapturedFiles()
     }
     QDir dir(KdenliveSettings::capturefolder());
     QStringList filters;
-    filters << "capture*" + extension;
+    QString capturename = KdenliveSettings::dvgrabfilename();
+    if (capturename.isEmpty()) capturename = "capture";
+    filters << capturename + "*" + extension;
     const QStringList result = dir.entryList(filters, QDir::Files, QDir::Time);
     KUrl::List capturedFiles;
     foreach(const QString &name, result) {
@@ -618,7 +649,21 @@ void RecMonitor::manageCapturedFiles()
 // virtual
 void RecMonitor::mousePressEvent(QMouseEvent * /*event*/)
 {
-    slotPlay();
+#if KDE_IS_VERSION(4,2,0)
+    if (m_freeSpace->underMouse()) slotUpdateFreeSpace();
+#endif
+}
+
+void RecMonitor::slotUpdateFreeSpace()
+{
+#if KDE_IS_VERSION(4,2,0)
+    KDiskFreeSpaceInfo info = KDiskFreeSpaceInfo::freeSpaceInfo(KdenliveSettings::capturefolder());
+    if (info.isValid()) {
+        m_freeSpace->setValue(100 * info.used() / info.size());
+        m_freeSpace->setText(i18n("Free space: %1", KIO::convertSize(info.available())));
+        m_freeSpace->update();
+    }
+#endif
 }
 
 void RecMonitor::activateRecMonitor()
@@ -653,5 +698,13 @@ void RecMonitor::slotPlay()
 
 }
 
+void RecMonitor::slotReadDvgrabInfo()
+{
+    QString data = m_captureProcess->readAllStandardError().simplified();
+    data = data.section('"', 2, 2).simplified();
+    m_dvinfo.setText(data.left(11));
+    m_dvinfo.updateGeometry();
+}
 
 #include "recmonitor.moc"
+
