@@ -29,6 +29,10 @@
 #include <QList>
 #include <QEvent>
 
+#ifdef Q_WS_MAC
+#include "videoglwidget.h"
+#endif
+
 
 /**Render encapsulates the client side of the interface to a renderer.
 From Kdenlive's point of view, you treat the Render object as the
@@ -77,12 +81,13 @@ Q_OBJECT public:
                       APP_NOEXIST
                     };
 
-    Render(const QString & rendererName, int winid, int extid, QWidget *parent = 0);
+    Render(const QString & rendererName, int winid, int extid, QString profile = QString(), QWidget *parent = 0);
     ~Render();
 
     /** Seeks the renderer clip to the given time. */
     void seek(GenTime time);
     void seekToFrame(int pos);
+    void seekToFrameDiff(int diff);
     int m_isBlocked;
 
     //static QPixmap getVideoThumbnail(char *profile, QString file, int frame, int width, int height);
@@ -122,7 +127,7 @@ Q_OBJECT public:
     void stop(const GenTime & startTime);
     void setVolume(double volume);
 
-    QPixmap extractFrame(int frame_position, int width = -1, int height = -1);
+    QImage extractFrame(int frame_position, int width = -1, int height = -1);
     /** Wraps the VEML command of the same name. Tells the renderer to
     play the current scene at the speed specified, relative to normal
     playback. e.g. 1.0 is normal speed, 0.0 is paused, -1.0 means play
@@ -141,6 +146,7 @@ Q_OBJECT public:
     double playSpeed();
     /** Returns the current seek position of the renderer. */
     GenTime seekPosition() const;
+    int seekFramePosition() const;
 
     void emitFrameNumber(double position);
     void emitConsumerStopped();
@@ -148,7 +154,6 @@ Q_OBJECT public:
     /** Gives the aspect ratio of the consumer */
     double consumerRatio() const;
 
-    void askForRefresh();
     void doRefresh();
 
     /** Save current producer frame as image */
@@ -156,7 +161,7 @@ Q_OBJECT public:
 
     /** Turn on or off on screen display */
     void refreshDisplay();
-    int resetProfile();
+    int resetProfile(const QString profileName);
     double fps() const;
     int renderWidth() const;
     int renderHeight() const;
@@ -164,8 +169,8 @@ Q_OBJECT public:
     double dar() const;
 
     /** Playlist manipulation */
-    void mltInsertClip(ItemInfo info, QDomElement element, Mlt::Producer *prod);
-    void mltUpdateClip(ItemInfo info, QDomElement element, Mlt::Producer *prod);
+    int mltInsertClip(ItemInfo info, QDomElement element, Mlt::Producer *prod);
+    bool mltUpdateClip(ItemInfo info, QDomElement element, Mlt::Producer *prod);
     void mltCutClip(int track, GenTime position);
     void mltInsertSpace(QMap <int, int> trackClipStartList, QMap <int, int> trackTransitionStartList, int track, const GenTime duration, const GenTime timeOffset);
     int mltGetSpaceLength(const GenTime pos, int track, bool fromBlankStart);
@@ -176,10 +181,17 @@ Q_OBJECT public:
     bool mltMoveClip(int startTrack, int endTrack, GenTime pos, GenTime moveStart, Mlt::Producer *prod);
     bool mltMoveClip(int startTrack, int endTrack, int pos, int moveStart, Mlt::Producer *prod);
     bool mltRemoveClip(int track, GenTime position);
+    /** Delete an effect to a clip in MLT's playlist */
     bool mltRemoveEffect(int track, GenTime position, QString index, bool updateIndex, bool doRefresh = true);
+    /** Add an effect to a clip in MLT's playlist */
     bool mltAddEffect(int track, GenTime position, EffectsParameterList params, bool doRefresh = true);
+    /** Edit an effect parameters in MLT */
     bool mltEditEffect(int track, GenTime position, EffectsParameterList params);
+    /** This only updates the "kdenlive_ix" (index) value of an effect */
+    void mltUpdateEffectPosition(int track, GenTime position, int oldPos, int newPos);
+    /** This changes the order of effects in MLT, inverting effects from oldPos and newPos, also updating the kdenlive_ix value */
     void mltMoveEffect(int track, GenTime position, int oldPos, int newPos);
+    /** This changes the state of a track, enabling / disabling audio and video */
     void mltChangeTrackState(int track, bool mute, bool blind);
     bool mltMoveTransition(QString type, int startTrack,  int newTrack, int newTransitionTrack, GenTime oldIn, GenTime oldOut, GenTime newIn, GenTime newOut);
     bool mltAddTransition(QString tag, int a_track, int b_track, GenTime in, GenTime out, QDomElement xml, bool refresh = true);
@@ -192,18 +204,22 @@ Q_OBJECT public:
     void mltResizeTransparency(int oldStart, int newStart, int newEnd, int track, int id);
     void mltInsertTrack(int ix, bool videoTrack);
     void mltDeleteTrack(int ix);
-    void mltUpdateClipProducer(int track, int pos, Mlt::Producer *prod);
+    bool mltUpdateClipProducer(int track, int pos, Mlt::Producer *prod);
 
     /** Change speed of a clip in playlist. To do this, we create a new "framebuffer" producer.
     This new producer must have its "resource" param set to: video.mpg?0.6 where video.mpg is the path
     to the clip and 0.6 is the speed in percents. The newly created producer will have it's
     "id" parameter set to: "slowmotion:parentid:speed", where parentid is the id of the original clip
     in the ClipManager list and speed is the current speed */
-    int mltChangeClipSpeed(ItemInfo info, double speed, double oldspeed, Mlt::Producer *prod);
+    int mltChangeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, double speed, double oldspeed, int strobe, Mlt::Producer *prod);
 
-    QList <Mlt::Producer *> producersList();
+    const QList <Mlt::Producer *> producersList();
     void updatePreviewSettings();
     void setDropFrames(bool show);
+    QString updateSceneListFps(double current_fps, double new_fps, QString scene);
+#ifdef Q_WS_MAC
+    void showFrame(Mlt::Frame&);
+#endif
 
 private:   // Private attributes & methods
     /** The name of this renderer - useful to identify the renderes by what they do - e.g. background rendering, workspace monitor, etc... */
@@ -226,19 +242,22 @@ private:   // Private attributes & methods
     Mlt::Producer *m_blackClip;
     QString m_activeProfile;
 
-    QTimer *m_refreshTimer;
     QTimer *m_osdTimer;
 
     /** A human-readable description of this renderer. */
     int m_winid;
 
+#ifdef Q_WS_MAC
+    VideoGLWidget *m_glWidget;
+#endif
+
     /** Sets the description of this renderer to desc. */
     void closeMlt();
-    void mltCheckLength();
+    void mltCheckLength(Mlt::Tractor *tractor);
     void mltPasteEffects(Mlt::Producer *source, Mlt::Producer *dest);
     QMap<QString, QString> mltGetTransitionParamsFromXml(QDomElement xml);
     QMap<QString, Mlt::Producer *> m_slowmotionProducers;
-    void buildConsumer();
+    void buildConsumer(const QString profileName);
     void resetZoneMode();
     void fillSlowMotionProducers();
 
@@ -274,13 +293,14 @@ signals:   // Signals
     void removeInvalidClip(const QString &, bool replaceProducer);
     void refreshDocumentProducers();
     void blockMonitors();
+    /** Used on OS X - emitted when a frame's image is to be shown. */
+    void showImageSignal(QImage);
 
 public slots:  // Public slots
     /** Start Consumer */
     void start();
     /** Stop Consumer */
     void stop();
-    void clear();
     int getLength();
     /** If the file is readable by mlt, return true, otherwise false */
     bool isValid(KUrl url);
@@ -288,7 +308,7 @@ public slots:  // Public slots
     /** Wraps the VEML command of the same name. Requests the file properties
     for the specified url from the renderer. Upon return, the result will be emitted
     via replyGetFileProperties(). */
-    void getFileProperties(const QDomElement &xml, const QString &clipId, bool replaceProducer = true);
+    void getFileProperties(const QDomElement xml, const QString &clipId, bool replaceProducer = true);
 
     void exportFileToFirewire(QString srcFileName, int port, GenTime startTime, GenTime endTime);
     static char *decodedString(QString str);
