@@ -24,6 +24,7 @@
 #include "renderer.h"
 #include "graphicsscenerectmove.h"
 #include "unicodedialog.h"
+#include "timecode.h"
 
 #include <QMap>
 #include <QSignalMapper>
@@ -48,7 +49,7 @@ class TitleWidget : public QDialog , public Ui::TitleWidget_UI
 public:
     /** \brief Constructor
      * \param projectPath Path to use when user requests loading or saving of titles as .kdenlivetitle documents */
-    TitleWidget(KUrl url, QString projectTitlePath, Render *render, QWidget *parent = 0);
+    TitleWidget(KUrl url, Timecode tc, QString projectTitlePath, Render *render, QWidget *parent = 0);
     virtual ~TitleWidget();
     QDomDocument xml();
     void setXml(QDomDocument doc);
@@ -70,18 +71,21 @@ public:
      * returned. */
     static QString getTitleResourceFromName(const KUrl &projectUrl, const QString &titleName);
 
-    /** \brief returns the size of the rendered pixmap
-    *
-    */
-    const QRect renderedRect();
+    /** \brief Get clip duration. */
+    int duration() const;
 
 protected:
     virtual void resizeEvent(QResizeEvent * event);
 
 private:
-    QGraphicsPolygonItem *m_startViewport, *m_endViewport;
+    /** \brief Rectangle describing animation start viewport */
+    QGraphicsRectItem *m_startViewport;
+    /** \brief Rectangle describing animation end viewport */
+    QGraphicsRectItem *m_endViewport;
+    /** \brief Scene for the titler */
     GraphicsSceneRectMove *m_scene;
-    void initViewports();
+    /** \brief Initialize the animation properties (viewport size,...) */
+    void initAnimation();
     QMap<QGraphicsItem*, Transform > m_transformations;
     TitleDocument m_titledocument;
     QGraphicsRectItem *m_frameBorder;
@@ -98,16 +102,21 @@ private:
     QAction *m_buttonLoad;
 
     QAction *m_unicodeAction;
+
     /** \brief Dialog for entering unicode in text fields */
     UnicodeDialog *m_unicodeDialog;
     /** project path for storing title clips */
     QString m_projectTitlePath;
+    Timecode m_tc;
 
     /** See http://doc.trolltech.com/4.5/signalsandslots.html#advanced-signals-and-slots-usage */
     QSignalMapper *m_signalMapper;
 
     enum ValueType { ValueWidth = 0, ValueHeight = 1 };
 
+    /** \brief Sets the font weight value in the combo box. (#909) */
+    void setFontBoxWeight(int weight);
+
     /** \brief Store the current choices of font, background and rect values */
     void writeChoices();
     /** \brief Read the last stored choices into the dialog */
@@ -132,6 +141,16 @@ private:
     void enableToolbars(TITLETOOL toolType);
     /** \brief Shows the toolbars suiting to toolType */
     void showToolbars(TITLETOOL toolType);
+    /** \brief Check a tool button. */
+    void checkButton(TITLETOOL toolType);
+
+    void adjustFrameSize();
+    /** \brief Add a "start" and "end" info text to the animation viewports */
+    void addAnimInfoText();
+    /** \brief Update font for the "start" and "end" info text */
+    void updateInfoText();
+    /** \brief Remove the "start" and "end" info text from animation viewports */
+    void deleteAnimInfoText();
 
 public slots:
     void slotNewText(QGraphicsTextItem *tt);
@@ -143,11 +162,8 @@ public slots:
     void zIndexChanged(int);
     void itemScaled(int);
     void itemRotate(int);
-    void itemHCenter();
-    void itemVCenter();
     void saveTitle(KUrl url = KUrl());
-    void loadTitle();
-    QImage renderedPixmap();
+    void loadTitle(KUrl url = KUrl());
 
 private slots:
     void slotAdjustSelectedItem();
@@ -216,6 +232,19 @@ private slots:
     void slotSelectTool();
     void slotImageTool();
 
+    void slotAnimStart(bool);
+    void slotAnimEnd(bool);
+    void slotKeepAspect(bool keep);
+
+    void itemHCenter();
+    void itemVCenter();
+    void itemTop();
+    void itemBottom();
+    void itemLeft();
+    void itemRight();
+    void slotResize50();
+    void slotResize100();
+    void slotResize200();
 
     /** \brief Called when accepted, stores the user selections for next time use */
     void slotAccepted();
