@@ -30,11 +30,14 @@
 #include "mainwindow.h"
 #include "customtrackview.h"
 #include "initeffects.h"
+#include "profilesdialog.h"
 
 #include <KDebug>
 #include <KMessageBox>
+#include <KIO/NetAccess>
 
 #include <QScrollBar>
+#include <QInputDialog>
 
 TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
         QWidget(parent),
@@ -44,8 +47,9 @@ TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
         m_verticalZoom(1)
 {
 
-    m_view.setupUi(this);
-
+    setupUi(this);
+//    ruler_frame->setMaximumHeight();
+//    size_frame->setMaximumHeight();
     m_scene = new CustomTrackScene(doc);
     m_trackview = new CustomTrackView(doc, m_scene, parent);
     m_trackview->scale(1, 1);
@@ -54,53 +58,51 @@ TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
 
     m_ruler = new CustomRuler(doc->timecode(), m_trackview);
     connect(m_ruler, SIGNAL(zoneMoved(int, int)), this, SIGNAL(zoneMoved(int, int)));
+    connect(m_ruler, SIGNAL(adjustZoom(int)), this, SIGNAL(setZoom(int)));
     QHBoxLayout *layout = new QHBoxLayout;
     layout->setContentsMargins(m_trackview->frameWidth(), 0, 0, 0);
     layout->setSpacing(0);
-    m_view.ruler_frame->setLayout(layout);
+    ruler_frame->setLayout(layout);
     layout->addWidget(m_ruler);
 
-
     QHBoxLayout *sizeLayout = new QHBoxLayout;
     sizeLayout->setContentsMargins(0, 0, 0, 0);
     sizeLayout->setSpacing(0);
-    m_view.size_frame->setLayout(sizeLayout);
-
-    QString style1 = "QToolButton {border-style: none;margin: 0px 3px;padding: 0px;} QToolButton:pressed:hover { background-color: rgba(224, 224, 0, 100); border-style: inset; border:1px solid #cc6666;border-radius: 3px;} QToolButton:hover { background-color: rgba(255, 255, 255, 100); border-style: inset; border:1px solid #cc6666;border-radius: 3px;}";
+    size_frame->setLayout(sizeLayout);
 
     QToolButton *butSmall = new QToolButton(this);
     butSmall->setIcon(KIcon("kdenlive-zoom-small"));
     butSmall->setToolTip(i18n("Smaller tracks"));
+    butSmall->setAutoRaise(true);
     connect(butSmall, SIGNAL(clicked()), this, SLOT(slotVerticalZoomDown()));
     sizeLayout->addWidget(butSmall);
 
     QToolButton *butLarge = new QToolButton(this);
     butLarge->setIcon(KIcon("kdenlive-zoom-large"));
     butLarge->setToolTip(i18n("Bigger tracks"));
+    butLarge->setAutoRaise(true);
     connect(butLarge, SIGNAL(clicked()), this, SLOT(slotVerticalZoomUp()));
     sizeLayout->addWidget(butLarge);
-    m_view.size_frame->setStyleSheet(style1);
-
 
     QHBoxLayout *tracksLayout = new QHBoxLayout;
     tracksLayout->setContentsMargins(0, 0, 0, 0);
     tracksLayout->setSpacing(0);
-    m_view.tracks_frame->setLayout(tracksLayout);
+    tracks_frame->setLayout(tracksLayout);
 
-    m_view.headers_area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    m_view.headers_area->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    headers_area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    headers_area->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    headers_area->setFixedWidth(70);
 
-    m_headersLayout = new QVBoxLayout;
-    m_headersLayout->setContentsMargins(0, m_trackview->frameWidth(), 0, 0);
-    m_headersLayout->setSpacing(0);
-    m_view.headers_container->setLayout(m_headersLayout);
-
-    connect(m_view.headers_area->verticalScrollBar(), SIGNAL(valueChanged(int)), m_trackview->verticalScrollBar(), SLOT(setValue(int)));
+    QVBoxLayout *headersLayout = new QVBoxLayout;
+    headersLayout->setContentsMargins(0, m_trackview->frameWidth(), 0, 0);
+    headersLayout->setSpacing(0);
+    headers_container->setLayout(headersLayout);
+    connect(headers_area->verticalScrollBar(), SIGNAL(valueChanged(int)), m_trackview->verticalScrollBar(), SLOT(setValue(int)));
 
     tracksLayout->addWidget(m_trackview);
-
-    connect(m_trackview->verticalScrollBar(), SIGNAL(valueChanged(int)), m_view.headers_area->verticalScrollBar(), SLOT(setValue(int)));
+    connect(m_trackview->verticalScrollBar(), SIGNAL(valueChanged(int)), headers_area->verticalScrollBar(), SLOT(setValue(int)));
     connect(m_trackview, SIGNAL(trackHeightChanged()), this, SLOT(slotRebuildTrackHeaders()));
+    connect(m_trackview, SIGNAL(tracksChanged()), this, SLOT(slotReloadTracks()));
 
     parseDocument(m_doc->toXml());
     int error = m_doc->setSceneList();
@@ -241,10 +243,6 @@ void TrackView::parseDocument(QDomDocument doc)
                 p = playlists.item(j).toElement();
                 if (p.attribute("id") == playlist_name) break;
             }
-            int black_clips = p.childNodes().count();
-            for (int i = 0; i < black_clips; i++)
-                m_doc->loadingProgressed();
-            qApp->processEvents();
             pos--;
         }
     }
@@ -325,7 +323,11 @@ void TrackView::parseDocument(QDomDocument doc)
                                 if (e.attribute("type") == "double") {
                                     QString factor = e.attribute("factor", "1");
                                     if (factor != "1") {
-                                        double val = paramValue.toDouble() * factor.toDouble();
+                                        double fact;
+                                        if (factor.startsWith('%')) {
+                                            fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                                        } else fact = factor.toDouble();
+                                        double val = paramValue.toDouble() * fact;
                                         paramValue = QString::number(val);
                                     }
                                 }
@@ -343,6 +345,7 @@ void TrackView::parseDocument(QDomDocument doc)
             transitionInfo.startPos = GenTime(e.attribute("in").toInt(), m_doc->fps());
             transitionInfo.endPos = GenTime(e.attribute("out").toInt() + 1, m_doc->fps());
             transitionInfo.track = m_projectTracks - 1 - b_track;
+
             //kDebug() << "///////////////   +++++++++++  ADDING TRANSITION ON TRACK: " << b_track << ", TOTAL TRKA: " << m_projectTracks;
             if (transitionInfo.startPos >= transitionInfo.endPos) {
                 // invalid transition, remove it.
@@ -383,6 +386,18 @@ void TrackView::parseDocument(QDomDocument doc)
 
     slotRebuildTrackHeaders();
     if (!m_documentErrors.isNull()) KMessageBox::sorry(this, m_documentErrors);
+    if (infoXml.hasAttribute("upgraded")) {
+        // Our document was upgraded, create a backup copy just in case
+        QString baseFile = m_doc->url().path().section(".kdenlive", 0, 0);
+        int ct = 0;
+        QString backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
+        while (QFile::exists(backupFile)) {
+            ct++;
+            backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
+        }
+        if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this)) KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\n To make sure you don't loose data, a backup copy called: %1 was created.", backupFile));
+        else KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version, it was not possible to create a backup copy.", backupFile));
+    }
     //m_trackview->setCursorPos(cursorPos);
     //m_scrollBox->setGeometry(0, 0, 300 * zoomFactor(), m_scrollArea->height());
 }
@@ -405,7 +420,7 @@ void TrackView::moveCursorPos(int pos)
 void TrackView::slotChangeZoom(int horizontal, int vertical)
 {
     m_ruler->setPixelPerMark(horizontal);
-    m_scale = (double) FRAME_SIZE / m_ruler->comboScale[horizontal]; // m_ruler->comboScale[m_currentZoom] /
+    m_scale = (double) FRAME_SIZE / m_ruler->comboScale[horizontal];
 
     if (vertical == -1) {
         // user called zoom
@@ -438,18 +453,34 @@ void TrackView::refresh()
     m_trackview->viewport()->update();
 }
 
+void TrackView::slotReloadTracks()
+{
+    slotRebuildTrackHeaders();
+    emit updateTracksInfo();
+}
+
 void TrackView::slotRebuildTrackHeaders()
 {
-    QList <TrackInfo> list = m_doc->tracksList();
+    const QList <TrackInfo> list = m_doc->tracksList();
     QLayoutItem *child;
-    while ((child = m_headersLayout->takeAt(0)) != 0) {
-        if (child->widget()) delete child->widget();
+    while ((child = headers_container->layout()->takeAt(0)) != 0) {
+        QWidget *wid = child->widget();
         delete child;
+        if (wid) wid->deleteLater();
     }
     int max = list.count();
-    int height = KdenliveSettings::trackheight() * m_scene->scale().y();
+    int height = KdenliveSettings::trackheight() * m_scene->scale().y() - 1;
+    HeaderTrack *header = NULL;
+    QFrame *frame = NULL;
     for (int i = 0; i < max; i++) {
-        HeaderTrack *header = new HeaderTrack(i, list.at(max - i - 1), height, this);
+        frame = new QFrame(headers_container);
+        frame->setFixedHeight(1);
+        frame->setFrameStyle(QFrame::Plain);
+        frame->setFrameShape(QFrame::Box);
+        frame->setLineWidth(1);
+        headers_container->layout()->addWidget(frame);
+        TrackInfo info = list.at(max - i - 1);
+        header = new HeaderTrack(i, info, height, headers_container);
         connect(header, SIGNAL(switchTrackVideo(int)), m_trackview, SLOT(slotSwitchTrackVideo(int)));
         connect(header, SIGNAL(switchTrackAudio(int)), m_trackview, SLOT(slotSwitchTrackAudio(int)));
         connect(header, SIGNAL(switchTrackLock(int)), m_trackview, SLOT(slotSwitchTrackLock(int)));
@@ -457,18 +488,25 @@ void TrackView::slotRebuildTrackHeaders()
         connect(header, SIGNAL(deleteTrack(int)), this, SIGNAL(deleteTrack(int)));
         connect(header, SIGNAL(insertTrack(int)), this, SIGNAL(insertTrack(int)));
         connect(header, SIGNAL(changeTrack(int)), this, SIGNAL(changeTrack(int)));
-        m_headersLayout->addWidget(header);
+        connect(header, SIGNAL(renameTrack(int)), this, SLOT(slotRenameTrack(int)));
+        headers_container->layout()->addWidget(header);
     }
+    frame = new QFrame(this);
+    frame->setFixedHeight(1);
+    frame->setFrameStyle(QFrame::Plain);
+    frame->setFrameShape(QFrame::Box);
+    frame->setLineWidth(1);
+    headers_container->layout()->addWidget(frame);
 }
 
 
 void TrackView::adjustTrackHeaders()
 {
-    int height = KdenliveSettings::trackheight() * m_scene->scale().y();
+    int height = KdenliveSettings::trackheight() * m_scene->scale().y() - 1;
     QLayoutItem *child;
-    for (int i = 0; i < m_headersLayout->count(); i++) {
-        child = m_headersLayout->itemAt(i);
-        if (child->widget())(static_cast <HeaderTrack *>(child->widget()))->adjustSize(height);
+    for (int i = 0; i < headers_container->layout()->count(); i++) {
+        child = headers_container->layout()->itemAt(i);
+        if (child->widget() && child->widget()->height() > 5)(static_cast <HeaderTrack *>(child->widget()))->adjustSize(height);
     }
 }
 
@@ -483,8 +521,6 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
         if (elem.tagName() == "blank") {
             position += elem.attribute("length").toInt();
         } else if (elem.tagName() == "entry") {
-            m_doc->loadingProgressed();
-            qApp->processEvents();
             // Found a clip
             int in = elem.attribute("in").toInt();
             int out = elem.attribute("out").toInt();
@@ -497,9 +533,12 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
             QString idString = elem.attribute("producer");
             QString id = idString;
             double speed = 1.0;
+            int strobe = 1;
             if (idString.startsWith("slowmotion")) {
                 id = idString.section(':', 1, 1);
                 speed = idString.section(':', 2, 2).toDouble();
+                strobe = idString.section(':', 3, 3).toInt();
+                if (strobe == 0) strobe = 1;
             } else id = id.section('_', 0, 0);
             DocClipBase *clip = m_doc->clipManager()->getClipById(id);
             if (clip == NULL) {
@@ -538,15 +577,25 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 clipinfo.startPos = GenTime(position, m_doc->fps());
                 clipinfo.endPos = clipinfo.startPos + GenTime(out - in + 1, m_doc->fps());
                 clipinfo.cropStart = GenTime(in, m_doc->fps());
+                clipinfo.cropDuration = clipinfo.endPos - clipinfo.startPos;
+
                 clipinfo.track = ix;
                 //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
-                ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, false);
+                ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, strobe, false);
                 if (idString.endsWith("_video")) item->setVideoOnly(true);
                 else if (idString.endsWith("_audio")) item->setAudioOnly(true);
                 m_scene->addItem(item);
                 if (locked) item->setItemLocked(true);
                 clip->addReference();
                 position += (out - in + 1);
+                kDebug() << "/////////\n\n\n" << "CLIP SPEED: " << speed << ", " << strobe << "\n\n\n/////////////////////";
+                if (speed != 1.0 || strobe > 1) {
+                    QDomElement speedeffect = MainWindow::videoEffects.getEffectByTag(QString(), "speed").cloneNode().toElement();
+                    EffectsList::setParameter(speedeffect, "speed", QString::number((int)(100 * speed + 0.5)));
+                    EffectsList::setParameter(speedeffect, "strobe", QString::number(strobe));
+                    item->addEffect(speedeffect, false);
+                    item->effectsCounter();
+                }
 
                 // parse clip effects
                 QDomNodeList effects = elem.childNodes();
@@ -597,7 +646,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                             if (MainWindow::videoEffects.hasKeyFrames(currenteffect)) {
                                 //kDebug() << " * * * * * * * * * * ** CLIP EFF WITH KFR FND  * * * * * * * * * * *";
                                 // effect is key-framable, read all effects to retrieve keyframes
-                                double factor = 0;
+                                QString factor;
                                 QString starttag;
                                 QString endtag;
                                 QDomNodeList params = currenteffect.elementsByTagName("parameter");
@@ -606,7 +655,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                     if (e.attribute("type") == "keyframe") {
                                         starttag = e.attribute("starttag", "start");
                                         endtag = e.attribute("endtag", "end");
-                                        factor = e.attribute("factor", "1").toDouble();
+                                        factor = e.attribute("factor", "1");
                                         break;
                                     }
                                 }
@@ -615,13 +664,18 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                 int effectout = effect.attribute("out").toInt();
                                 double startvalue = 0;
                                 double endvalue = 0;
+                                double fact;
+                                if (factor.isEmpty()) fact = 1;
+                                else if (factor.startsWith('%')) {
+                                    fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                                } else fact = factor.toDouble();
                                 for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
                                     // parse effect parameters
                                     QDomElement effectparam = n3.toElement();
                                     if (effectparam.attribute("name") == starttag)
-                                        startvalue = effectparam.text().toDouble() * factor;
+                                        startvalue = effectparam.text().toDouble() * fact;
                                     if (effectparam.attribute("name") == endtag)
-                                        endvalue = effectparam.text().toDouble() * factor;
+                                        endvalue = effectparam.text().toDouble() * fact;
                                 }
                                 // add first keyframe
                                 keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
@@ -644,7 +698,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                             continueParsing = false;
                                             break;
                                         } else if (subeffectparam.attribute("name") == endtag) {
-                                            endvalue = subeffectparam.text().toDouble() * factor;
+                                            endvalue = subeffectparam.text().toDouble() * fact;
                                             break;
                                         }
                                     }
@@ -685,9 +739,13 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                 for (int k = 0; k < clipeffectparams.count(); k++) {
                                     e = clipeffectparams.item(k).toElement();
                                     if (!e.isNull() && e.tagName() == "parameter" && e.attribute("name") == paramname) {
-                                        double factor = e.attribute("factor", "1").toDouble();
-                                        if (factor != 1) {
-                                            e.setAttribute("value", paramvalue.toDouble() * factor);
+                                        if (e.attribute("factor", "1") != "1") {
+                                            QString factor = e.attribute("factor", "1");
+                                            double fact;
+                                            if (factor.startsWith('%')) {
+                                                fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                                            } else fact = factor.toDouble();
+                                            e.setAttribute("value", paramvalue.toDouble() * fact);
                                         } else e.setAttribute("value", paramvalue);
                                         break;
                                     }
@@ -750,8 +808,10 @@ DocClipBase *TrackView::getMissingProducer(const QString id) const
     // prepend MLT XML document root if no path in clip resource and not a color clip
     if (!resource.startsWith('/') && !resource.startsWith("0x")) resource.prepend(docRoot);
     DocClipBase *missingClip = NULL;
-    if (!resource.isEmpty())
-        missingClip = m_doc->clipManager()->getClipByResource(resource);
+    if (!resource.isEmpty()) {
+        QList <DocClipBase *> list = m_doc->clipManager()->getClipByResource(resource);
+        if (!list.isEmpty()) missingClip = list.at(0);
+    }
     return missingClip;
 }
 
@@ -781,6 +841,7 @@ void TrackView::slotChangeTrackLock(int ix, bool lock)
     widgets.at(ix)->setLock(lock);
 }
 
+
 void TrackView::slotVerticalZoomDown()
 {
     if (m_verticalZoom == 0) return;
@@ -789,8 +850,7 @@ void TrackView::slotVerticalZoomDown()
     if (m_verticalZoom == 0) m_trackview->setScale(m_scene->scale().x(), 0.5);
     else m_trackview->setScale(m_scene->scale().x(), 1);
     adjustTrackHeaders();
-    /*KdenliveSettings::setTrackheight(KdenliveSettings::trackheight() / 2);
-    m_trackview->checkTrackHeight(false);*/
+    m_trackview->verticalScrollBar()->setValue(headers_area->verticalScrollBar()->value());
 }
 
 void TrackView::slotVerticalZoomUp()
@@ -798,11 +858,31 @@ void TrackView::slotVerticalZoomUp()
     if (m_verticalZoom == 2) return;
     m_verticalZoom++;
     m_doc->setZoom(m_doc->zoom().x(), m_verticalZoom);
-    /*KdenliveSettings::setTrackheight(KdenliveSettings::trackheight() * 2);
-    m_trackview->checkTrackHeight(false);*/
     if (m_verticalZoom == 2) m_trackview->setScale(m_scene->scale().x(), 2);
     else m_trackview->setScale(m_scene->scale().x(), 1);
     adjustTrackHeaders();
+    m_trackview->verticalScrollBar()->setValue(headers_area->verticalScrollBar()->value());
 }
 
+void TrackView::updateProjectFps()
+{
+    m_ruler->updateProjectFps(m_doc->timecode());
+    m_trackview->updateProjectFps();
+}
+
+void TrackView::slotRenameTrack(int ix)
+{
+    int tracknumber = m_doc->tracksCount() - ix;
+    TrackInfo info = m_doc->trackInfoAt(tracknumber - 1);
+    bool ok;
+    QString newName = QInputDialog::getText(this, i18n("New Track Name"), i18n("Enter new name"), QLineEdit::Normal, info.trackName, &ok);
+    if (ok) {
+        info.trackName = newName;
+        m_doc->setTrackType(tracknumber - 1, info);
+        QTimer::singleShot(300, this, SLOT(slotReloadTracks()));
+        m_doc->setModified(true);
+    }
+}
+
+
 #include "trackview.moc"
